"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CustomerTypedDict(TypedDict):
    r"""Customer information"""

    customer_id_as_printed: NotRequired[str]
    r"""The client/customer identifier in the document"""
    name: NotRequired[str]
    r"""Information about the customer sending the remittance advice"""
    address: NotRequired[str]
    r"""Customer address information"""


class Customer(BaseModel):
    r"""Customer information"""

    customer_id_as_printed: Annotated[
        Optional[str], pydantic.Field(alias="customerIdAsPrinted")
    ] = None
    r"""The client/customer identifier in the document"""

    name: Optional[str] = None
    r"""Information about the customer sending the remittance advice"""

    address: Optional[str] = None
    r"""Customer address information"""


class RemittanceAdviceFieldsVendorTypedDict(TypedDict):
    r"""Vendor information"""

    vendor_id_as_printed: NotRequired[str]
    r"""The vendor's identifier in the document"""
    name: NotRequired[str]
    r"""Information about the vendor receiving the remittance advice"""
    address: NotRequired[str]
    r"""Vendor address information"""


class RemittanceAdviceFieldsVendor(BaseModel):
    r"""Vendor information"""

    vendor_id_as_printed: Annotated[
        Optional[str], pydantic.Field(alias="vendorIdAsPrinted")
    ] = None
    r"""The vendor's identifier in the document"""

    name: Optional[str] = None
    r"""Information about the vendor receiving the remittance advice"""

    address: Optional[str] = None
    r"""Vendor address information"""


class PaymentInformationTypedDict(TypedDict):
    r"""Payment information details"""

    payment_number: NotRequired[str]
    r"""The payment registration or invoice number"""
    payment_date: NotRequired[date]
    r"""The payment or invoice date"""
    payment_amount: NotRequired[float]
    r"""The payment amount"""
    currency: NotRequired[str]
    r"""The currency of the payment"""


class PaymentInformation(BaseModel):
    r"""Payment information details"""

    payment_number: Annotated[Optional[str], pydantic.Field(alias="paymentNumber")] = (
        None
    )
    r"""The payment registration or invoice number"""

    payment_date: Annotated[Optional[date], pydantic.Field(alias="paymentDate")] = None
    r"""The payment or invoice date"""

    payment_amount: Annotated[
        Optional[float], pydantic.Field(alias="paymentAmount")
    ] = None
    r"""The payment amount"""

    currency: Optional[str] = None
    r"""The currency of the payment"""


class RemittanceAdviceFieldsLineItemsTypedDict(TypedDict):
    r"""Line item details"""

    invoice_number: NotRequired[str]
    r"""The number of the invoice"""
    invoice_date: NotRequired[date]
    r"""The date on which the invoice was issued"""
    paid_amount: NotRequired[float]
    r"""The total invoice amount paid"""
    invoice_amount: NotRequired[float]
    r"""The total invoice amount"""
    discount: NotRequired[float]
    r"""The discount applicable to the invoice amount"""
    type: NotRequired[str]
    r"""The invoice type (Debit or Credit)"""
    customer_id: NotRequired[str]
    r"""The client/customer identifier"""


class RemittanceAdviceFieldsLineItems(BaseModel):
    r"""Line item details"""

    invoice_number: Annotated[Optional[str], pydantic.Field(alias="invoiceNumber")] = (
        None
    )
    r"""The number of the invoice"""

    invoice_date: Annotated[Optional[date], pydantic.Field(alias="invoiceDate")] = None
    r"""The date on which the invoice was issued"""

    paid_amount: Annotated[Optional[float], pydantic.Field(alias="paidAmount")] = None
    r"""The total invoice amount paid"""

    invoice_amount: Annotated[
        Optional[float], pydantic.Field(alias="invoiceAmount")
    ] = None
    r"""The total invoice amount"""

    discount: Optional[float] = None
    r"""The discount applicable to the invoice amount"""

    type: Optional[str] = None
    r"""The invoice type (Debit or Credit)"""

    customer_id: Annotated[Optional[str], pydantic.Field(alias="customerId")] = None
    r"""The client/customer identifier"""


class RemittanceAdviceFieldsTypedDict(TypedDict):
    r"""Fields extracted from a remittance advice"""

    customer: NotRequired[CustomerTypedDict]
    r"""Customer information"""
    vendor: NotRequired[RemittanceAdviceFieldsVendorTypedDict]
    r"""Vendor information"""
    payment_information: NotRequired[PaymentInformationTypedDict]
    r"""Payment information details"""
    total: NotRequired[float]
    r"""The total amount paid"""
    bank_key: NotRequired[str]
    r"""The bank identifier. This field is optional and may have the name of the bank as its value if no bank identifier is found"""
    line_items: NotRequired[List[RemittanceAdviceFieldsLineItemsTypedDict]]
    r"""Array of line items in the remittance advice"""


class RemittanceAdviceFields(BaseModel):
    r"""Fields extracted from a remittance advice"""

    customer: Optional[Customer] = None
    r"""Customer information"""

    vendor: Optional[RemittanceAdviceFieldsVendor] = None
    r"""Vendor information"""

    payment_information: Annotated[
        Optional[PaymentInformation], pydantic.Field(alias="paymentInformation")
    ] = None
    r"""Payment information details"""

    total: Optional[float] = None
    r"""The total amount paid"""

    bank_key: Annotated[Optional[str], pydantic.Field(alias="bankKey")] = None
    r"""The bank identifier. This field is optional and may have the name of the bank as its value if no bank identifier is found"""

    line_items: Annotated[
        Optional[List[RemittanceAdviceFieldsLineItems]],
        pydantic.Field(alias="lineItems"),
    ] = None
    r"""Array of line items in the remittance advice"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class USForm1040FieldsFormTypedDict(TypedDict):
    r"""Specifies whether the form is 1040 or 1040-SR"""

    one_thousand_and_forty: NotRequired[bool]
    one_thousand_and_forty_sr: NotRequired[bool]


class USForm1040FieldsForm(BaseModel):
    r"""Specifies whether the form is 1040 or 1040-SR"""

    one_thousand_and_forty: Annotated[Optional[bool], pydantic.Field(alias="1040")] = (
        None
    )

    one_thousand_and_forty_sr: Annotated[
        Optional[bool], pydantic.Field(alias="1040Sr")
    ] = None


class USForm1040FieldsFilingStatusTypedDict(TypedDict):
    r"""The taxpayer's filing status"""

    head_of_household: NotRequired[bool]
    married_filing_jointly: NotRequired[bool]
    married_filing_separately: NotRequired[bool]
    qualifying_surviving_spouse: NotRequired[bool]
    single: NotRequired[bool]


class USForm1040FieldsFilingStatus(BaseModel):
    r"""The taxpayer's filing status"""

    head_of_household: Annotated[
        Optional[bool], pydantic.Field(alias="headOfHousehold")
    ] = None

    married_filing_jointly: Annotated[
        Optional[bool], pydantic.Field(alias="marriedFilingJointly")
    ] = None

    married_filing_separately: Annotated[
        Optional[bool], pydantic.Field(alias="marriedFilingSeparately")
    ] = None

    qualifying_surviving_spouse: Annotated[
        Optional[bool], pydantic.Field(alias="qualifyingSurvivingSpouse")
    ] = None

    single: Optional[bool] = None


class USForm1040FieldsSpouseTypedDict(TypedDict):
    r"""The name and social security number of the taxpayer's spouse (if filing jointly)"""

    spouses_first_name: NotRequired[str]
    r"""Spouse's first name"""
    spouses_last_name: NotRequired[str]
    r"""Spouse's last name"""
    spouses_ssn: NotRequired[str]
    r"""Spouse's SSN"""


class USForm1040FieldsSpouse(BaseModel):
    r"""The name and social security number of the taxpayer's spouse (if filing jointly)"""

    spouses_first_name: Annotated[
        Optional[str], pydantic.Field(alias="spousesFirstName")
    ] = None
    r"""Spouse's first name"""

    spouses_last_name: Annotated[
        Optional[str], pydantic.Field(alias="spousesLastName")
    ] = None
    r"""Spouse's last name"""

    spouses_ssn: Annotated[Optional[str], pydantic.Field(alias="spousesSsn")] = None
    r"""Spouse's SSN"""


class USForm1040FieldsAddressTypedDict(TypedDict):
    r"""The taxpayer's address"""

    home_address: NotRequired[str]
    r"""Home address"""
    apartment_number: NotRequired[str]
    r"""Apartment number"""
    city_town_or_post_office: NotRequired[str]
    r"""City, town or post office"""
    state: NotRequired[str]
    r"""State"""
    zip_code: NotRequired[str]
    r"""ZIP code"""
    foreign_country_name: NotRequired[str]
    r"""Foreign country name"""
    foreign_province_or_state_or_country: NotRequired[str]
    r"""Foreign province or state or country"""
    foreign_postal_code: NotRequired[str]
    r"""Foreign postal code"""


class USForm1040FieldsAddress(BaseModel):
    r"""The taxpayer's address"""

    home_address: Annotated[Optional[str], pydantic.Field(alias="homeAddress")] = None
    r"""Home address"""

    apartment_number: Annotated[
        Optional[str], pydantic.Field(alias="apartmentNumber")
    ] = None
    r"""Apartment number"""

    city_town_or_post_office: Annotated[
        Optional[str], pydantic.Field(alias="cityTownOrPostOffice")
    ] = None
    r"""City, town or post office"""

    state: Optional[str] = None
    r"""State"""

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zipCode")] = None
    r"""ZIP code"""

    foreign_country_name: Annotated[
        Optional[str], pydantic.Field(alias="foreignCountryName")
    ] = None
    r"""Foreign country name"""

    foreign_province_or_state_or_country: Annotated[
        Optional[str], pydantic.Field(alias="foreignProvinceOrStateOrCountry")
    ] = None
    r"""Foreign province or state or country"""

    foreign_postal_code: Annotated[
        Optional[str], pydantic.Field(alias="foreignPostalCode")
    ] = None
    r"""Foreign postal code"""


class USForm1040FieldsPresidentialElectionCampaignTypedDict(TypedDict):
    r"""Indicates whether payments have been made to a Presidential election camping fund by the taxpayer or his/her spouse (if filing jointly)"""

    you: NotRequired[bool]
    r"""Indicates whether payments have been made to a Presidential election camping fund by the taxpayer"""
    spouse: NotRequired[bool]
    r"""Indicates whether payments have been made to a Presidential election camping fund by the spouse"""


class USForm1040FieldsPresidentialElectionCampaign(BaseModel):
    r"""Indicates whether payments have been made to a Presidential election camping fund by the taxpayer or his/her spouse (if filing jointly)"""

    you: Optional[bool] = None
    r"""Indicates whether payments have been made to a Presidential election camping fund by the taxpayer"""

    spouse: Optional[bool] = None
    r"""Indicates whether payments have been made to a Presidential election camping fund by the spouse"""


class DigitalAssetsTypedDict(TypedDict):
    r"""Indicates whether there was any income related to virtual currencies for the reporting period"""

    yes: bool
    no: bool


class DigitalAssets(BaseModel):
    r"""Indicates whether there was any income related to virtual currencies for the reporting period"""

    yes: bool

    no: bool


class USForm1040FieldsSomeoneCanClaimTypedDict(TypedDict):
    r"""Indicates whether the taxpayer and/or their spouse can be claimed as dependents"""

    you_as_a_dependent: NotRequired[bool]
    r"""Indicates whether the taxpayer can be claimed as a dependent"""
    your_spouse_as_a_dependent: NotRequired[bool]
    r"""Indicates whether the spouse can be claimed as a dependent"""


class USForm1040FieldsSomeoneCanClaim(BaseModel):
    r"""Indicates whether the taxpayer and/or their spouse can be claimed as dependents"""

    you_as_a_dependent: Annotated[
        Optional[bool], pydantic.Field(alias="youAsADependent")
    ] = None
    r"""Indicates whether the taxpayer can be claimed as a dependent"""

    your_spouse_as_a_dependent: Annotated[
        Optional[bool], pydantic.Field(alias="yourSpouseAsADependent")
    ] = None
    r"""Indicates whether the spouse can be claimed as a dependent"""


class USForm1040FieldsYouTypedDict(TypedDict):
    r"""Indicates whether the taxpayer was born before January 2, 1958, and whether he/she is blind"""

    born_before_january21958: NotRequired[bool]
    r"""Indicates whether the taxpayer was born before January 2, 1958"""
    blind: NotRequired[bool]
    r"""Indicates whether the taxpayer is blind"""


class USForm1040FieldsYou(BaseModel):
    r"""Indicates whether the taxpayer was born before January 2, 1958, and whether he/she is blind"""

    born_before_january21958: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21958")
    ] = None
    r"""Indicates whether the taxpayer was born before January 2, 1958"""

    blind: Optional[bool] = None
    r"""Indicates whether the taxpayer is blind"""


class USForm1040Fields2SpouseTypedDict(TypedDict):
    r"""Indicates whether the spouse was born before January 2, 1958, and whether he/she is blind"""

    born_before_january21958: NotRequired[bool]
    r"""Indicates whether the spouse was born before January 2, 1958"""
    blind: NotRequired[bool]
    r"""Indicates whether the spouse is blind"""


class USForm1040Fields2Spouse(BaseModel):
    r"""Indicates whether the spouse was born before January 2, 1958, and whether he/she is blind"""

    born_before_january21958: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21958")
    ] = None
    r"""Indicates whether the spouse was born before January 2, 1958"""

    blind: Optional[bool] = None
    r"""Indicates whether the spouse is blind"""


class USForm1040FieldsAgeOrBlindnessTypedDict(TypedDict):
    r"""Indicates whether the taxpayer or his/her spouse (if filing jointly) was born before January 2, 1958, and whether he/she is blind"""

    you: NotRequired[USForm1040FieldsYouTypedDict]
    r"""Indicates whether the taxpayer was born before January 2, 1958, and whether he/she is blind"""
    spouse: NotRequired[USForm1040Fields2SpouseTypedDict]
    r"""Indicates whether the spouse was born before January 2, 1958, and whether he/she is blind"""


class USForm1040FieldsAgeOrBlindness(BaseModel):
    r"""Indicates whether the taxpayer or his/her spouse (if filing jointly) was born before January 2, 1958, and whether he/she is blind"""

    you: Optional[USForm1040FieldsYou] = None
    r"""Indicates whether the taxpayer was born before January 2, 1958, and whether he/she is blind"""

    spouse: Optional[USForm1040Fields2Spouse] = None
    r"""Indicates whether the spouse was born before January 2, 1958, and whether he/she is blind"""


class USForm1040FieldsStandardDeductionTypedDict(TypedDict):
    r"""Standard deduction information"""

    someone_can_claim: NotRequired[USForm1040FieldsSomeoneCanClaimTypedDict]
    r"""Indicates whether the taxpayer and/or their spouse can be claimed as dependents"""
    separate_return_or_dual_status_alien: NotRequired[bool]
    r"""Indicates whether the taxpayer is filing for separate returns and whether the taxpayer is a dual-status alien"""
    age_or_blindness: NotRequired[USForm1040FieldsAgeOrBlindnessTypedDict]
    r"""Indicates whether the taxpayer or his/her spouse (if filing jointly) was born before January 2, 1958, and whether he/she is blind"""
    more_than_four_dependents: NotRequired[bool]
    r"""Indicated whether the taxpayer has more than four dependents"""


class USForm1040FieldsStandardDeduction(BaseModel):
    r"""Standard deduction information"""

    someone_can_claim: Annotated[
        Optional[USForm1040FieldsSomeoneCanClaim],
        pydantic.Field(alias="someoneCanClaim"),
    ] = None
    r"""Indicates whether the taxpayer and/or their spouse can be claimed as dependents"""

    separate_return_or_dual_status_alien: Annotated[
        Optional[bool], pydantic.Field(alias="separateReturnOrDualStatusAlien")
    ] = None
    r"""Indicates whether the taxpayer is filing for separate returns and whether the taxpayer is a dual-status alien"""

    age_or_blindness: Annotated[
        Optional[USForm1040FieldsAgeOrBlindness], pydantic.Field(alias="ageOrBlindness")
    ] = None
    r"""Indicates whether the taxpayer or his/her spouse (if filing jointly) was born before January 2, 1958, and whether he/she is blind"""

    more_than_four_dependents: Annotated[
        Optional[bool], pydantic.Field(alias="moreThanFourDependents")
    ] = None
    r"""Indicated whether the taxpayer has more than four dependents"""


class USForm1040FieldsDependentsTypedDict(TypedDict):
    r"""Information about the dependents"""

    full_name: NotRequired[str]
    r"""Dependent's full name"""
    ssn: NotRequired[str]
    r"""Dependent's SSN"""
    relationship: NotRequired[str]
    r"""Relationship to taxpayer"""
    child_tax_credit: NotRequired[bool]
    r"""Child tax credit eligibility"""
    credit_for_other_dependents: NotRequired[bool]
    r"""Credit for other dependents eligibility"""


class USForm1040FieldsDependents(BaseModel):
    r"""Information about the dependents"""

    full_name: Annotated[Optional[str], pydantic.Field(alias="fullName")] = None
    r"""Dependent's full name"""

    ssn: Optional[str] = None
    r"""Dependent's SSN"""

    relationship: Optional[str] = None
    r"""Relationship to taxpayer"""

    child_tax_credit: Annotated[
        Optional[bool], pydantic.Field(alias="childTaxCredit")
    ] = None
    r"""Child tax credit eligibility"""

    credit_for_other_dependents: Annotated[
        Optional[bool], pydantic.Field(alias="creditForOtherDependents")
    ] = None
    r"""Credit for other dependents eligibility"""


class Box1GroupTypedDict(TypedDict):
    r"""Box 1 group information"""

    box1a_total_amount_from_form_w2_box1: NotRequired[float]
    r"""Total amount from Form W-2 Box 1"""
    box1b_household_employee_wages: NotRequired[float]
    r"""Household employee wages"""
    box1c_tip_income: NotRequired[float]
    r"""Tip income"""
    box1d_medicaid_waiver_payments: NotRequired[float]
    r"""Medicaid waiver payments"""
    box1e_taxable_dependent_care_benefits_from_form2441: NotRequired[float]
    r"""Taxable dependent care benefits from Form 2441"""
    box1f_employer_provided_adoption_benefits_from_form8839: NotRequired[float]
    r"""Employer-provided adoption benefits from Form 8839"""
    box1g_wages_from_form8919: NotRequired[float]
    r"""Wages from Form 8919"""
    box1h_other_earned_income: NotRequired[float]
    r"""Other earned income"""
    box1i_nontaxable_combat_pay_election: NotRequired[float]
    r"""Nontaxable combat pay election"""
    box1z_group_total: NotRequired[float]
    r"""Group total"""


class Box1Group(BaseModel):
    r"""Box 1 group information"""

    box1a_total_amount_from_form_w2_box1: Annotated[
        Optional[float], pydantic.Field(alias="box1aTotalAmountFromFormW2Box1")
    ] = None
    r"""Total amount from Form W-2 Box 1"""

    box1b_household_employee_wages: Annotated[
        Optional[float], pydantic.Field(alias="box1bHouseholdEmployeeWages")
    ] = None
    r"""Household employee wages"""

    box1c_tip_income: Annotated[
        Optional[float], pydantic.Field(alias="box1cTipIncome")
    ] = None
    r"""Tip income"""

    box1d_medicaid_waiver_payments: Annotated[
        Optional[float], pydantic.Field(alias="box1dMedicaidWaiverPayments")
    ] = None
    r"""Medicaid waiver payments"""

    box1e_taxable_dependent_care_benefits_from_form2441: Annotated[
        Optional[float],
        pydantic.Field(alias="box1eTaxableDependentCareBenefitsFromForm2441"),
    ] = None
    r"""Taxable dependent care benefits from Form 2441"""

    box1f_employer_provided_adoption_benefits_from_form8839: Annotated[
        Optional[float],
        pydantic.Field(alias="box1fEmployerProvidedAdoptionBenefitsFromForm8839"),
    ] = None
    r"""Employer-provided adoption benefits from Form 8839"""

    box1g_wages_from_form8919: Annotated[
        Optional[float], pydantic.Field(alias="box1gWagesFromForm8919")
    ] = None
    r"""Wages from Form 8919"""

    box1h_other_earned_income: Annotated[
        Optional[float], pydantic.Field(alias="box1hOtherEarnedIncome")
    ] = None
    r"""Other earned income"""

    box1i_nontaxable_combat_pay_election: Annotated[
        Optional[float], pydantic.Field(alias="box1iNontaxableCombatPayElection")
    ] = None
    r"""Nontaxable combat pay election"""

    box1z_group_total: Annotated[
        Optional[float], pydantic.Field(alias="box1zGroupTotal")
    ] = None
    r"""Group total"""


class Box2GroupTypedDict(TypedDict):
    r"""Box 2 group information"""

    box2a_tax_exempt_interest: NotRequired[float]
    r"""Tax-exempt interest"""
    box2b_taxable_interest: NotRequired[float]
    r"""Taxable interest"""


class Box2Group(BaseModel):
    r"""Box 2 group information"""

    box2a_tax_exempt_interest: Annotated[
        Optional[float], pydantic.Field(alias="box2aTaxExemptInterest")
    ] = None
    r"""Tax-exempt interest"""

    box2b_taxable_interest: Annotated[
        Optional[float], pydantic.Field(alias="box2bTaxableInterest")
    ] = None
    r"""Taxable interest"""


class Box3GroupTypedDict(TypedDict):
    r"""Box 3 group information"""

    box3a_qualified_dividends: NotRequired[float]
    r"""Qualified dividends"""
    box3b_ordinary_dividends: NotRequired[float]
    r"""Ordinary dividends"""


class Box3Group(BaseModel):
    r"""Box 3 group information"""

    box3a_qualified_dividends: Annotated[
        Optional[float], pydantic.Field(alias="box3aQualifiedDividends")
    ] = None
    r"""Qualified dividends"""

    box3b_ordinary_dividends: Annotated[
        Optional[float], pydantic.Field(alias="box3bOrdinaryDividends")
    ] = None
    r"""Ordinary dividends"""


class Box4GroupTypedDict(TypedDict):
    r"""Box 4 group information"""

    box4a_ira_distributions: NotRequired[float]
    r"""IRA distributions"""
    box4b_taxable_amount: NotRequired[float]
    r"""Taxable amount"""


class Box4Group(BaseModel):
    r"""Box 4 group information"""

    box4a_ira_distributions: Annotated[
        Optional[float], pydantic.Field(alias="box4aIraDistributions")
    ] = None
    r"""IRA distributions"""

    box4b_taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="box4bTaxableAmount")
    ] = None
    r"""Taxable amount"""


class Box5GroupTypedDict(TypedDict):
    r"""Box 5 group information"""

    box5a_pensions_and_annuities: NotRequired[float]
    r"""Pensions and annuities"""
    box5b_taxable_amount: NotRequired[float]
    r"""Taxable amount"""


class Box5Group(BaseModel):
    r"""Box 5 group information"""

    box5a_pensions_and_annuities: Annotated[
        Optional[float], pydantic.Field(alias="box5aPensionsAndAnnuities")
    ] = None
    r"""Pensions and annuities"""

    box5b_taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="box5bTaxableAmount")
    ] = None
    r"""Taxable amount"""


class Box6GroupTypedDict(TypedDict):
    r"""Box 6 group information"""

    box6a_social_security_benefits: NotRequired[float]
    r"""Social Security benefits"""
    box6b_taxable_amount: NotRequired[float]
    r"""Taxable amount"""
    box6c_use_the_lump_sum_election_method: NotRequired[bool]
    r"""Use the lump-sum election method"""


class Box6Group(BaseModel):
    r"""Box 6 group information"""

    box6a_social_security_benefits: Annotated[
        Optional[float], pydantic.Field(alias="box6aSocialSecurityBenefits")
    ] = None
    r"""Social Security benefits"""

    box6b_taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="box6bTaxableAmount")
    ] = None
    r"""Taxable amount"""

    box6c_use_the_lump_sum_election_method: Annotated[
        Optional[bool], pydantic.Field(alias="box6cUseTheLumpSumElectionMethod")
    ] = None
    r"""Use the lump-sum election method"""


class Box7GroupTypedDict(TypedDict):
    r"""Box 7 group information"""

    schedule_d_not_required: NotRequired[bool]
    r"""Schedule D not required"""
    box7_capital_gain_or_loss: NotRequired[float]
    r"""Capital gain or loss"""


class Box7Group(BaseModel):
    r"""Box 7 group information"""

    schedule_d_not_required: Annotated[
        Optional[bool], pydantic.Field(alias="scheduleDNotRequired")
    ] = None
    r"""Schedule D not required"""

    box7_capital_gain_or_loss: Annotated[
        Optional[float], pydantic.Field(alias="box7CapitalGainOrLoss")
    ] = None
    r"""Capital gain or loss"""


class Box16GroupTypedDict(TypedDict):
    r"""Box 16 group information"""

    one_form8814: NotRequired[bool]
    r"""Form 8814 amount"""
    two_form4972: NotRequired[bool]
    r"""Form 4972 amount"""
    three_other_form: NotRequired[bool]
    r"""Other form amount"""
    other_form_name: NotRequired[str]
    r"""Other form name"""
    box16_tax: NotRequired[float]
    r"""Tax amount"""


class Box16Group(BaseModel):
    r"""Box 16 group information"""

    one_form8814: Annotated[Optional[bool], pydantic.Field(alias="1Form8814")] = None
    r"""Form 8814 amount"""

    two_form4972: Annotated[Optional[bool], pydantic.Field(alias="2Form4972")] = None
    r"""Form 4972 amount"""

    three_other_form: Annotated[Optional[bool], pydantic.Field(alias="3OtherForm")] = (
        None
    )
    r"""Other form amount"""

    other_form_name: Annotated[Optional[str], pydantic.Field(alias="otherFormName")] = (
        None
    )
    r"""Other form name"""

    box16_tax: Annotated[Optional[float], pydantic.Field(alias="box16Tax")] = None
    r"""Tax amount"""


class Box25GroupFederalIncomeTaxTypedDict(TypedDict):
    r"""Box 25 group information"""

    box25a_form_w2: NotRequired[float]
    r"""Form W-2 amount"""
    box25b_form1099: NotRequired[float]
    r"""Form 1099 amount"""
    box25c_other_forms: NotRequired[float]
    r"""Other forms amount"""
    box25d_group_total: NotRequired[float]
    r"""Group total"""


class Box25GroupFederalIncomeTax(BaseModel):
    r"""Box 25 group information"""

    box25a_form_w2: Annotated[Optional[float], pydantic.Field(alias="box25aFormW2")] = (
        None
    )
    r"""Form W-2 amount"""

    box25b_form1099: Annotated[
        Optional[float], pydantic.Field(alias="box25bForm1099")
    ] = None
    r"""Form 1099 amount"""

    box25c_other_forms: Annotated[
        Optional[float], pydantic.Field(alias="box25cOtherForms")
    ] = None
    r"""Other forms amount"""

    box25d_group_total: Annotated[
        Optional[float], pydantic.Field(alias="box25dGroupTotal")
    ] = None
    r"""Group total"""


class Box35cTypeTypedDict(TypedDict):
    r"""Account type"""

    checking: bool
    saving: bool


class Box35cType(BaseModel):
    r"""Account type"""

    checking: bool

    saving: bool


class Box35GroupTypedDict(TypedDict):
    r"""Box 35 group information"""

    box35a_form8888_attached: NotRequired[bool]
    r"""Form 8888 attached"""
    box35a_refundable_amount: NotRequired[float]
    r"""Refundable amount"""
    box35b_routing_number: NotRequired[str]
    r"""Routing number"""
    box35c_type: NotRequired[Box35cTypeTypedDict]
    r"""Account type"""
    box35d_account_number: NotRequired[str]
    r"""Account number"""


class Box35Group(BaseModel):
    r"""Box 35 group information"""

    box35a_form8888_attached: Annotated[
        Optional[bool], pydantic.Field(alias="box35aForm8888Attached")
    ] = None
    r"""Form 8888 attached"""

    box35a_refundable_amount: Annotated[
        Optional[float], pydantic.Field(alias="box35aRefundableAmount")
    ] = None
    r"""Refundable amount"""

    box35b_routing_number: Annotated[
        Optional[str], pydantic.Field(alias="box35bRoutingNumber")
    ] = None
    r"""Routing number"""

    box35c_type: Annotated[Optional[Box35cType], pydantic.Field(alias="box35cType")] = (
        None
    )
    r"""Account type"""

    box35d_account_number: Annotated[
        Optional[str], pydantic.Field(alias="box35dAccountNumber")
    ] = None
    r"""Account number"""


class USForm1040FieldsAnotherPersonCanDiscussWithIrsTypedDict(TypedDict):
    r"""Another person can discuss with IRS"""

    no: bool
    yes: bool


class USForm1040FieldsAnotherPersonCanDiscussWithIrs(BaseModel):
    r"""Another person can discuss with IRS"""

    no: bool

    yes: bool


class USForm1040FieldsThirdPartyDesigneeTypedDict(TypedDict):
    r"""The contact information of the taxpayer's representative that is authorized to discuss the taxpayer's return with the IRS"""

    another_person_can_discuss_with_irs: NotRequired[
        USForm1040FieldsAnotherPersonCanDiscussWithIrsTypedDict
    ]
    r"""Another person can discuss with IRS"""
    designees_name: NotRequired[str]
    r"""Designee's name"""
    phone_number: NotRequired[str]
    r"""Phone number"""
    pin: NotRequired[str]
    r"""PIN"""


class USForm1040FieldsThirdPartyDesignee(BaseModel):
    r"""The contact information of the taxpayer's representative that is authorized to discuss the taxpayer's return with the IRS"""

    another_person_can_discuss_with_irs: Annotated[
        Optional[USForm1040FieldsAnotherPersonCanDiscussWithIrs],
        pydantic.Field(alias="anotherPersonCanDiscussWithIrs"),
    ] = None
    r"""Another person can discuss with IRS"""

    designees_name: Annotated[Optional[str], pydantic.Field(alias="designeesName")] = (
        None
    )
    r"""Designee's name"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""Phone number"""

    pin: Optional[str] = None
    r"""PIN"""


class USForm1040FieldsSignatureTypedDict(TypedDict):
    r"""The taxpayer's signature"""

    date_: NotRequired[date]
    r"""Date"""
    occupation: NotRequired[str]
    r"""Occupation"""
    identity_protection_pin: NotRequired[str]
    r"""Identity protection PIN"""


class USForm1040FieldsSignature(BaseModel):
    r"""The taxpayer's signature"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""Date"""

    occupation: Optional[str] = None
    r"""Occupation"""

    identity_protection_pin: Annotated[
        Optional[str], pydantic.Field(alias="identityProtectionPin")
    ] = None
    r"""Identity protection PIN"""


class USForm1040FieldsSpousesSignatureTypedDict(TypedDict):
    r"""The spouse's signature (if filing jointly)"""

    date_: NotRequired[date]
    r"""Date"""
    occupation: NotRequired[str]
    r"""Occupation"""
    identity_protection_pin: NotRequired[str]
    r"""Identity protection PIN"""
    phone_number: NotRequired[str]
    r"""Phone number"""
    email_address: NotRequired[str]
    r"""Email address"""


class USForm1040FieldsSpousesSignature(BaseModel):
    r"""The spouse's signature (if filing jointly)"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""Date"""

    occupation: Optional[str] = None
    r"""Occupation"""

    identity_protection_pin: Annotated[
        Optional[str], pydantic.Field(alias="identityProtectionPin")
    ] = None
    r"""Identity protection PIN"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""Phone number"""

    email_address: Annotated[Optional[str], pydantic.Field(alias="emailAddress")] = None
    r"""Email address"""


class USForm1040FieldsPreparerTypedDict(TypedDict):
    r"""Details of the preparer of the tax return (if the return is completed and filed by a paid preparer)"""

    preparers_name: NotRequired[str]
    r"""Preparer's name"""
    date_: NotRequired[date]
    r"""Date"""
    ptin: NotRequired[str]
    r"""PTIN"""
    firms_name: NotRequired[str]
    r"""Firm's name"""
    firms_address: NotRequired[str]
    r"""Firm's address"""
    phone_number: NotRequired[str]
    r"""Phone number"""
    firms_ein: NotRequired[str]
    r"""Firm's EIN"""
    self_employed: NotRequired[bool]
    r"""Self-employed"""


class USForm1040FieldsPreparer(BaseModel):
    r"""Details of the preparer of the tax return (if the return is completed and filed by a paid preparer)"""

    preparers_name: Annotated[Optional[str], pydantic.Field(alias="preparersName")] = (
        None
    )
    r"""Preparer's name"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""Date"""

    ptin: Optional[str] = None
    r"""PTIN"""

    firms_name: Annotated[Optional[str], pydantic.Field(alias="firmsName")] = None
    r"""Firm's name"""

    firms_address: Annotated[Optional[str], pydantic.Field(alias="firmsAddress")] = None
    r"""Firm's address"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""Phone number"""

    firms_ein: Annotated[Optional[str], pydantic.Field(alias="firmsEin")] = None
    r"""Firm's EIN"""

    self_employed: Annotated[Optional[bool], pydantic.Field(alias="selfEmployed")] = (
        None
    )
    r"""Self-employed"""


class USForm10402022TypedDict(TypedDict):
    r"""A US Form 1040 for 2022"""

    form: NotRequired[USForm1040FieldsFormTypedDict]
    r"""Specifies whether the form is 1040 or 1040-SR"""
    year: NotRequired[str]
    r"""Indicates the year of the form"""
    filing_status: NotRequired[USForm1040FieldsFilingStatusTypedDict]
    r"""The taxpayer's filing status"""
    name_of_mfs_spouse_or_hoh_or_qw_child: NotRequired[str]
    r"""The name of the taxpayer's spouse or child"""
    first_name: NotRequired[str]
    r"""The taxpayer's first name"""
    last_name: NotRequired[str]
    r"""The taxpayer's last name"""
    ssn: NotRequired[str]
    r"""The taxpayer's social security number"""
    spouse: NotRequired[USForm1040FieldsSpouseTypedDict]
    r"""The name and social security number of the taxpayer's spouse (if filing jointly)"""
    address: NotRequired[USForm1040FieldsAddressTypedDict]
    r"""The taxpayer's address"""
    presidential_election_campaign: NotRequired[
        USForm1040FieldsPresidentialElectionCampaignTypedDict
    ]
    r"""Indicates whether payments have been made to a Presidential election camping fund by the taxpayer or his/her spouse (if filing jointly)"""
    digital_assets: NotRequired[DigitalAssetsTypedDict]
    r"""Indicates whether there was any income related to virtual currencies for the reporting period"""
    standard_deduction: NotRequired[USForm1040FieldsStandardDeductionTypedDict]
    r"""Standard deduction information"""
    dependents: NotRequired[List[USForm1040FieldsDependentsTypedDict]]
    box1_group: NotRequired[Box1GroupTypedDict]
    r"""Box 1 group information"""
    box2_group: NotRequired[Box2GroupTypedDict]
    r"""Box 2 group information"""
    box3_group: NotRequired[Box3GroupTypedDict]
    r"""Box 3 group information"""
    box4_group: NotRequired[Box4GroupTypedDict]
    r"""Box 4 group information"""
    box5_group: NotRequired[Box5GroupTypedDict]
    r"""Box 5 group information"""
    box6_group: NotRequired[Box6GroupTypedDict]
    r"""Box 6 group information"""
    box7_group: NotRequired[Box7GroupTypedDict]
    r"""Box 7 group information"""
    box8_other_income_from_schedule1: NotRequired[float]
    r"""Other income from Schedule 1"""
    box9_total_income: NotRequired[float]
    r"""Total income"""
    box10_adjustments_to_income_from_schedule1: NotRequired[float]
    r"""Adjustments to income from Schedule 1"""
    box11_adjusted_gross_income: NotRequired[float]
    r"""Adjusted gross income"""
    box12_standard_deduction_or_itemized_deductions: NotRequired[float]
    r"""Standard deduction or itemized deductions"""
    box13_qualified_business_income_deduction: NotRequired[float]
    r"""Qualified business income deduction"""
    box14_total_of_boxes12_and13: NotRequired[float]
    r"""Total of boxes 12 and 13"""
    box15_taxable_income: NotRequired[float]
    r"""Taxable income"""
    box16_group: NotRequired[Box16GroupTypedDict]
    r"""Box 16 group information"""
    box17_amount_from_schedule2: NotRequired[float]
    r"""Amount from Schedule 2"""
    box18_total_of_boxes16_and17: NotRequired[float]
    r"""Total of boxes 16 and 17"""
    box19_child_tax_credit: NotRequired[float]
    r"""Child tax credit"""
    box20_amount_from_schedule3: NotRequired[float]
    r"""Amount from Schedule 3"""
    box21_total_of_boxes19_and20: NotRequired[float]
    r"""Total of boxes 19 and 20"""
    box22_tax_minus_child_tax_credit: NotRequired[float]
    r"""Tax minus child tax credit"""
    box23_other_taxes_including_self_employment_tax: NotRequired[float]
    r"""Other taxes including self-employment tax"""
    box24_total_tax: NotRequired[float]
    r"""Total tax"""
    box25_group_federal_income_tax: NotRequired[Box25GroupFederalIncomeTaxTypedDict]
    r"""Box 25 group information"""
    box262022_estimated_tax_payments_and_amount_applied_from2021_return: NotRequired[
        float
    ]
    r"""2022 estimated tax payments and amount applied from 2021 return"""
    box27_earned_income_credit: NotRequired[float]
    r"""Earned income credit"""
    box28_additional_child_tax_credit_from_schedule8812: NotRequired[float]
    r"""Additional child tax credit from Schedule 8812"""
    box29_american_opportunity_credit_from_form8863: NotRequired[float]
    r"""American opportunity credit from Form 8863"""
    box31_amount_from_schedule3: NotRequired[float]
    r"""Amount from Schedule 3"""
    box32_total_other_payments_and_refundable_credits: NotRequired[float]
    r"""Total other payments and refundable credits"""
    box33_total_payments: NotRequired[float]
    r"""Total payments"""
    box34_overpaid_amount: NotRequired[float]
    r"""Overpaid amount"""
    box35_group: NotRequired[Box35GroupTypedDict]
    r"""Box 35 group information"""
    box36_overpaid_amount_to_be_applied_to2023_estimated_tax: NotRequired[float]
    r"""Overpaid amount to be applied to 2023 estimated tax"""
    box37_owed_amount: NotRequired[float]
    r"""Owed amount"""
    box38_estimated_tax_penalty: NotRequired[float]
    r"""Estimated tax penalty"""
    third_party_designee: NotRequired[USForm1040FieldsThirdPartyDesigneeTypedDict]
    r"""The contact information of the taxpayer's representative that is authorized to discuss the taxpayer's return with the IRS"""
    signature: NotRequired[USForm1040FieldsSignatureTypedDict]
    r"""The taxpayer's signature"""
    spouses_signature: NotRequired[USForm1040FieldsSpousesSignatureTypedDict]
    r"""The spouse's signature (if filing jointly)"""
    preparer: NotRequired[USForm1040FieldsPreparerTypedDict]
    r"""Details of the preparer of the tax return (if the return is completed and filed by a paid preparer)"""


class USForm10402022(BaseModel):
    r"""A US Form 1040 for 2022"""

    form: Optional[USForm1040FieldsForm] = None
    r"""Specifies whether the form is 1040 or 1040-SR"""

    year: Optional[str] = None
    r"""Indicates the year of the form"""

    filing_status: Annotated[
        Optional[USForm1040FieldsFilingStatus], pydantic.Field(alias="filingStatus")
    ] = None
    r"""The taxpayer's filing status"""

    name_of_mfs_spouse_or_hoh_or_qw_child: Annotated[
        Optional[str], pydantic.Field(alias="nameOfMfsSpouseOrHohOrQwChild")
    ] = None
    r"""The name of the taxpayer's spouse or child"""

    first_name: Annotated[Optional[str], pydantic.Field(alias="firstName")] = None
    r"""The taxpayer's first name"""

    last_name: Annotated[Optional[str], pydantic.Field(alias="lastName")] = None
    r"""The taxpayer's last name"""

    ssn: Optional[str] = None
    r"""The taxpayer's social security number"""

    spouse: Optional[USForm1040FieldsSpouse] = None
    r"""The name and social security number of the taxpayer's spouse (if filing jointly)"""

    address: Optional[USForm1040FieldsAddress] = None
    r"""The taxpayer's address"""

    presidential_election_campaign: Annotated[
        Optional[USForm1040FieldsPresidentialElectionCampaign],
        pydantic.Field(alias="presidentialElectionCampaign"),
    ] = None
    r"""Indicates whether payments have been made to a Presidential election camping fund by the taxpayer or his/her spouse (if filing jointly)"""

    digital_assets: Annotated[
        Optional[DigitalAssets], pydantic.Field(alias="digitalAssets")
    ] = None
    r"""Indicates whether there was any income related to virtual currencies for the reporting period"""

    standard_deduction: Annotated[
        Optional[USForm1040FieldsStandardDeduction],
        pydantic.Field(alias="standardDeduction"),
    ] = None
    r"""Standard deduction information"""

    dependents: Optional[List[USForm1040FieldsDependents]] = None

    box1_group: Annotated[Optional[Box1Group], pydantic.Field(alias="box1Group")] = None
    r"""Box 1 group information"""

    box2_group: Annotated[Optional[Box2Group], pydantic.Field(alias="box2Group")] = None
    r"""Box 2 group information"""

    box3_group: Annotated[Optional[Box3Group], pydantic.Field(alias="box3Group")] = None
    r"""Box 3 group information"""

    box4_group: Annotated[Optional[Box4Group], pydantic.Field(alias="box4Group")] = None
    r"""Box 4 group information"""

    box5_group: Annotated[Optional[Box5Group], pydantic.Field(alias="box5Group")] = None
    r"""Box 5 group information"""

    box6_group: Annotated[Optional[Box6Group], pydantic.Field(alias="box6Group")] = None
    r"""Box 6 group information"""

    box7_group: Annotated[Optional[Box7Group], pydantic.Field(alias="box7Group")] = None
    r"""Box 7 group information"""

    box8_other_income_from_schedule1: Annotated[
        Optional[float], pydantic.Field(alias="box8OtherIncomeFromSchedule1")
    ] = None
    r"""Other income from Schedule 1"""

    box9_total_income: Annotated[
        Optional[float], pydantic.Field(alias="box9TotalIncome")
    ] = None
    r"""Total income"""

    box10_adjustments_to_income_from_schedule1: Annotated[
        Optional[float], pydantic.Field(alias="box10AdjustmentsToIncomeFromSchedule1")
    ] = None
    r"""Adjustments to income from Schedule 1"""

    box11_adjusted_gross_income: Annotated[
        Optional[float], pydantic.Field(alias="box11AdjustedGrossIncome")
    ] = None
    r"""Adjusted gross income"""

    box12_standard_deduction_or_itemized_deductions: Annotated[
        Optional[float],
        pydantic.Field(alias="box12StandardDeductionOrItemizedDeductions"),
    ] = None
    r"""Standard deduction or itemized deductions"""

    box13_qualified_business_income_deduction: Annotated[
        Optional[float], pydantic.Field(alias="box13QualifiedBusinessIncomeDeduction")
    ] = None
    r"""Qualified business income deduction"""

    box14_total_of_boxes12_and13: Annotated[
        Optional[float], pydantic.Field(alias="box14TotalOfBoxes12And13")
    ] = None
    r"""Total of boxes 12 and 13"""

    box15_taxable_income: Annotated[
        Optional[float], pydantic.Field(alias="box15TaxableIncome")
    ] = None
    r"""Taxable income"""

    box16_group: Annotated[Optional[Box16Group], pydantic.Field(alias="box16Group")] = (
        None
    )
    r"""Box 16 group information"""

    box17_amount_from_schedule2: Annotated[
        Optional[float], pydantic.Field(alias="box17AmountFromSchedule2")
    ] = None
    r"""Amount from Schedule 2"""

    box18_total_of_boxes16_and17: Annotated[
        Optional[float], pydantic.Field(alias="box18TotalOfBoxes16And17")
    ] = None
    r"""Total of boxes 16 and 17"""

    box19_child_tax_credit: Annotated[
        Optional[float], pydantic.Field(alias="box19ChildTaxCredit")
    ] = None
    r"""Child tax credit"""

    box20_amount_from_schedule3: Annotated[
        Optional[float], pydantic.Field(alias="box20AmountFromSchedule3")
    ] = None
    r"""Amount from Schedule 3"""

    box21_total_of_boxes19_and20: Annotated[
        Optional[float], pydantic.Field(alias="box21TotalOfBoxes19And20")
    ] = None
    r"""Total of boxes 19 and 20"""

    box22_tax_minus_child_tax_credit: Annotated[
        Optional[float], pydantic.Field(alias="box22TaxMinusChildTaxCredit")
    ] = None
    r"""Tax minus child tax credit"""

    box23_other_taxes_including_self_employment_tax: Annotated[
        Optional[float],
        pydantic.Field(alias="box23OtherTaxesIncludingSelfEmploymentTax"),
    ] = None
    r"""Other taxes including self-employment tax"""

    box24_total_tax: Annotated[
        Optional[float], pydantic.Field(alias="box24TotalTax")
    ] = None
    r"""Total tax"""

    box25_group_federal_income_tax: Annotated[
        Optional[Box25GroupFederalIncomeTax],
        pydantic.Field(alias="box25GroupFederalIncomeTax"),
    ] = None
    r"""Box 25 group information"""

    box262022_estimated_tax_payments_and_amount_applied_from2021_return: Annotated[
        Optional[float],
        pydantic.Field(
            alias="box262022EstimatedTaxPaymentsAndAmountAppliedFrom2021Return"
        ),
    ] = None
    r"""2022 estimated tax payments and amount applied from 2021 return"""

    box27_earned_income_credit: Annotated[
        Optional[float], pydantic.Field(alias="box27EarnedIncomeCredit")
    ] = None
    r"""Earned income credit"""

    box28_additional_child_tax_credit_from_schedule8812: Annotated[
        Optional[float],
        pydantic.Field(alias="box28AdditionalChildTaxCreditFromSchedule8812"),
    ] = None
    r"""Additional child tax credit from Schedule 8812"""

    box29_american_opportunity_credit_from_form8863: Annotated[
        Optional[float],
        pydantic.Field(alias="box29AmericanOpportunityCreditFromForm8863"),
    ] = None
    r"""American opportunity credit from Form 8863"""

    box31_amount_from_schedule3: Annotated[
        Optional[float], pydantic.Field(alias="box31AmountFromSchedule3")
    ] = None
    r"""Amount from Schedule 3"""

    box32_total_other_payments_and_refundable_credits: Annotated[
        Optional[float],
        pydantic.Field(alias="box32TotalOtherPaymentsAndRefundableCredits"),
    ] = None
    r"""Total other payments and refundable credits"""

    box33_total_payments: Annotated[
        Optional[float], pydantic.Field(alias="box33TotalPayments")
    ] = None
    r"""Total payments"""

    box34_overpaid_amount: Annotated[
        Optional[float], pydantic.Field(alias="box34OverpaidAmount")
    ] = None
    r"""Overpaid amount"""

    box35_group: Annotated[Optional[Box35Group], pydantic.Field(alias="box35Group")] = (
        None
    )
    r"""Box 35 group information"""

    box36_overpaid_amount_to_be_applied_to2023_estimated_tax: Annotated[
        Optional[float],
        pydantic.Field(alias="box36OverpaidAmountToBeAppliedTo2023EstimatedTax"),
    ] = None
    r"""Overpaid amount to be applied to 2023 estimated tax"""

    box37_owed_amount: Annotated[
        Optional[float], pydantic.Field(alias="box37OwedAmount")
    ] = None
    r"""Owed amount"""

    box38_estimated_tax_penalty: Annotated[
        Optional[float], pydantic.Field(alias="box38EstimatedTaxPenalty")
    ] = None
    r"""Estimated tax penalty"""

    third_party_designee: Annotated[
        Optional[USForm1040FieldsThirdPartyDesignee],
        pydantic.Field(alias="thirdPartyDesignee"),
    ] = None
    r"""The contact information of the taxpayer's representative that is authorized to discuss the taxpayer's return with the IRS"""

    signature: Optional[USForm1040FieldsSignature] = None
    r"""The taxpayer's signature"""

    spouses_signature: Annotated[
        Optional[USForm1040FieldsSpousesSignature],
        pydantic.Field(alias="spousesSignature"),
    ] = None
    r"""The spouse's signature (if filing jointly)"""

    preparer: Optional[USForm1040FieldsPreparer] = None
    r"""Details of the preparer of the tax return (if the return is completed and filed by a paid preparer)"""


class FormTypedDict(TypedDict):
    r"""Specifies whether the form is 1040 or 1040-SR"""

    one_thousand_and_forty: NotRequired[bool]
    one_thousand_and_forty_sr: NotRequired[bool]


class Form(BaseModel):
    r"""Specifies whether the form is 1040 or 1040-SR"""

    one_thousand_and_forty: Annotated[Optional[bool], pydantic.Field(alias="1040")] = (
        None
    )

    one_thousand_and_forty_sr: Annotated[
        Optional[bool], pydantic.Field(alias="1040Sr")
    ] = None


class FilingStatusTypedDict(TypedDict):
    r"""The taxpayer's filing status"""

    head: NotRequired[bool]
    joint: NotRequired[bool]
    separately: NotRequired[bool]
    single: NotRequired[bool]
    widow: NotRequired[bool]


class FilingStatus(BaseModel):
    r"""The taxpayer's filing status"""

    head: Optional[bool] = None

    joint: Optional[bool] = None

    separately: Optional[bool] = None

    single: Optional[bool] = None

    widow: Optional[bool] = None


class SpouseTypedDict(TypedDict):
    spouses_first_name: NotRequired[str]
    r"""Spouse's first name"""
    spouses_last_name: NotRequired[str]
    r"""Spouse's last name"""
    spouses_ssn: NotRequired[str]
    r"""Spouse's social security number"""


class Spouse(BaseModel):
    spouses_first_name: Annotated[
        Optional[str], pydantic.Field(alias="spousesFirstName")
    ] = None
    r"""Spouse's first name"""

    spouses_last_name: Annotated[
        Optional[str], pydantic.Field(alias="spousesLastName")
    ] = None
    r"""Spouse's last name"""

    spouses_ssn: Annotated[Optional[str], pydantic.Field(alias="spousesSsn")] = None
    r"""Spouse's social security number"""


class AddressTypedDict(TypedDict):
    home_address: NotRequired[str]
    r"""Home address"""
    apartment_number: NotRequired[str]
    r"""Apartment number"""
    city_town_or_post_office: NotRequired[str]
    r"""City, town or post office"""
    city_town_or_post_office_state_and_zip_code_outdated: NotRequired[str]
    r"""City, town or post office state and zip code (outdated)"""
    state: NotRequired[str]
    r"""State"""
    zip_code: NotRequired[str]
    r"""ZIP code"""
    foreign_country_name: NotRequired[str]
    r"""Foreign country name"""
    foreign_province_or_state_or_country: NotRequired[str]
    r"""Foreign province or state or country"""
    foreign_postal_code: NotRequired[str]
    r"""Foreign postal code"""


class Address(BaseModel):
    home_address: Annotated[Optional[str], pydantic.Field(alias="homeAddress")] = None
    r"""Home address"""

    apartment_number: Annotated[
        Optional[str], pydantic.Field(alias="apartmentNumber")
    ] = None
    r"""Apartment number"""

    city_town_or_post_office: Annotated[
        Optional[str], pydantic.Field(alias="cityTownOrPostOffice")
    ] = None
    r"""City, town or post office"""

    city_town_or_post_office_state_and_zip_code_outdated: Annotated[
        Optional[str],
        pydantic.Field(alias="cityTownOrPostOfficeStateAndZipCodeOutdated"),
    ] = None
    r"""City, town or post office state and zip code (outdated)"""

    state: Optional[str] = None
    r"""State"""

    zip_code: Annotated[Optional[str], pydantic.Field(alias="zipCode")] = None
    r"""ZIP code"""

    foreign_country_name: Annotated[
        Optional[str], pydantic.Field(alias="foreignCountryName")
    ] = None
    r"""Foreign country name"""

    foreign_province_or_state_or_country: Annotated[
        Optional[str], pydantic.Field(alias="foreignProvinceOrStateOrCountry")
    ] = None
    r"""Foreign province or state or country"""

    foreign_postal_code: Annotated[
        Optional[str], pydantic.Field(alias="foreignPostalCode")
    ] = None
    r"""Foreign postal code"""


class PresidentialElectionCampaignTypedDict(TypedDict):
    you: NotRequired[bool]
    r"""Indicates whether payments have been made by the taxpayer"""
    spouse: NotRequired[bool]
    r"""Indicates whether payments have been made by the spouse"""


class PresidentialElectionCampaign(BaseModel):
    you: Optional[bool] = None
    r"""Indicates whether payments have been made by the taxpayer"""

    spouse: Optional[bool] = None
    r"""Indicates whether payments have been made by the spouse"""


class FinancialInterestInVirtualCurrencyDuringThisYearTypedDict(TypedDict):
    r"""Indicates whether there was any income related to virtual currencies"""

    yes: bool
    no: bool


class FinancialInterestInVirtualCurrencyDuringThisYear(BaseModel):
    r"""Indicates whether there was any income related to virtual currencies"""

    yes: bool

    no: bool


class SomeoneCanClaimTypedDict(TypedDict):
    you_as_a_dependent: NotRequired[bool]
    r"""Indicates whether the taxpayer can be claimed as a dependent"""
    your_spouse_as_a_dependent: NotRequired[bool]
    r"""Indicates whether the spouse can be claimed as a dependent"""


class SomeoneCanClaim(BaseModel):
    you_as_a_dependent: Annotated[
        Optional[bool], pydantic.Field(alias="youAsADependent")
    ] = None
    r"""Indicates whether the taxpayer can be claimed as a dependent"""

    your_spouse_as_a_dependent: Annotated[
        Optional[bool], pydantic.Field(alias="yourSpouseAsADependent")
    ] = None
    r"""Indicates whether the spouse can be claimed as a dependent"""


class YouTypedDict(TypedDict):
    born_before_january21957: NotRequired[bool]
    born_before_january21956_outdated: NotRequired[bool]
    born_before_january21955_outdated: NotRequired[bool]
    born_before_january21954_outdated: NotRequired[bool]
    blind: NotRequired[bool]


class You(BaseModel):
    born_before_january21957: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21957")
    ] = None

    born_before_january21956_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21956Outdated")
    ] = None

    born_before_january21955_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21955Outdated")
    ] = None

    born_before_january21954_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21954Outdated")
    ] = None

    blind: Optional[bool] = None


class USForm1040Fields1SpouseTypedDict(TypedDict):
    born_before_january21957: NotRequired[bool]
    born_before_january21956_outdated: NotRequired[bool]
    born_before_january21955_outdated: NotRequired[bool]
    born_before_january21954_outdated: NotRequired[bool]
    blind: NotRequired[bool]


class USForm1040Fields1Spouse(BaseModel):
    born_before_january21957: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21957")
    ] = None

    born_before_january21956_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21956Outdated")
    ] = None

    born_before_january21955_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21955Outdated")
    ] = None

    born_before_january21954_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="bornBeforeJanuary21954Outdated")
    ] = None

    blind: Optional[bool] = None


class AgeOrBlindnessTypedDict(TypedDict):
    you: NotRequired[YouTypedDict]
    spouse: NotRequired[USForm1040Fields1SpouseTypedDict]


class AgeOrBlindness(BaseModel):
    you: Optional[You] = None

    spouse: Optional[USForm1040Fields1Spouse] = None


class StandardDeductionTypedDict(TypedDict):
    someone_can_claim: NotRequired[SomeoneCanClaimTypedDict]
    separate_return_or_dual_status_alien: NotRequired[bool]
    r"""Indicates whether filing separate returns or is a dual-status alien"""
    age_or_blindness: NotRequired[AgeOrBlindnessTypedDict]


class StandardDeduction(BaseModel):
    someone_can_claim: Annotated[
        Optional[SomeoneCanClaim], pydantic.Field(alias="someoneCanClaim")
    ] = None

    separate_return_or_dual_status_alien: Annotated[
        Optional[bool], pydantic.Field(alias="separateReturnOrDualStatusAlien")
    ] = None
    r"""Indicates whether filing separate returns or is a dual-status alien"""

    age_or_blindness: Annotated[
        Optional[AgeOrBlindness], pydantic.Field(alias="ageOrBlindness")
    ] = None


class DependentsTypedDict(TypedDict):
    full_name: NotRequired[str]
    r"""Dependent's full name"""
    ssn: NotRequired[str]
    r"""Dependent's social security number"""
    relationship: NotRequired[str]
    r"""Relationship to taxpayer"""
    child_tax_credit: NotRequired[bool]
    r"""Whether child tax credit applies"""
    credit_for_other_dependents: NotRequired[bool]
    r"""Whether credit for other dependents applies"""


class Dependents(BaseModel):
    full_name: Annotated[Optional[str], pydantic.Field(alias="fullName")] = None
    r"""Dependent's full name"""

    ssn: Optional[str] = None
    r"""Dependent's social security number"""

    relationship: Optional[str] = None
    r"""Relationship to taxpayer"""

    child_tax_credit: Annotated[
        Optional[bool], pydantic.Field(alias="childTaxCredit")
    ] = None
    r"""Whether child tax credit applies"""

    credit_for_other_dependents: Annotated[
        Optional[bool], pydantic.Field(alias="creditForOtherDependents")
    ] = None
    r"""Whether credit for other dependents applies"""


class TaxExemptInterestGroupTypedDict(TypedDict):
    tax_exempt_interest: NotRequired[float]
    r"""Tax-exempt interest"""
    taxable_interest: NotRequired[float]
    r"""Taxable interest"""


class TaxExemptInterestGroup(BaseModel):
    tax_exempt_interest: Annotated[
        Optional[float], pydantic.Field(alias="taxExemptInterest")
    ] = None
    r"""Tax-exempt interest"""

    taxable_interest: Annotated[
        Optional[float], pydantic.Field(alias="taxableInterest")
    ] = None
    r"""Taxable interest"""


class DividendsGroupTypedDict(TypedDict):
    qualified_dividends: NotRequired[float]
    r"""Qualified dividends"""
    ordinary_dividends: NotRequired[float]
    r"""Ordinary dividends"""


class DividendsGroup(BaseModel):
    qualified_dividends: Annotated[
        Optional[float], pydantic.Field(alias="qualifiedDividends")
    ] = None
    r"""Qualified dividends"""

    ordinary_dividends: Annotated[
        Optional[float], pydantic.Field(alias="ordinaryDividends")
    ] = None
    r"""Ordinary dividends"""


class IrasPensionsAndAnnuitiesGroupOutdatedTypedDict(TypedDict):
    iras_pensions_and_annuities_outdated: NotRequired[float]
    r"""IRAs, pensions and annuities (outdated)"""
    taxable_amount_outdated: NotRequired[float]
    r"""Taxable amount"""


class IrasPensionsAndAnnuitiesGroupOutdated(BaseModel):
    iras_pensions_and_annuities_outdated: Annotated[
        Optional[float], pydantic.Field(alias="irasPensionsAndAnnuitiesOutdated")
    ] = None
    r"""IRAs, pensions and annuities (outdated)"""

    taxable_amount_outdated: Annotated[
        Optional[float], pydantic.Field(alias="taxableAmountOutdated")
    ] = None
    r"""Taxable amount"""


class IraDistributionsGroupTypedDict(TypedDict):
    ira_distributions: NotRequired[float]
    r"""IRA distributions"""
    taxable_amount: NotRequired[float]
    r"""Taxable amount"""


class IraDistributionsGroup(BaseModel):
    ira_distributions: Annotated[
        Optional[float], pydantic.Field(alias="iraDistributions")
    ] = None
    r"""IRA distributions"""

    taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="taxableAmount")
    ] = None
    r"""Taxable amount"""


class PensionsAndAnnuitiesGroupTypedDict(TypedDict):
    pensions_and_annuities: NotRequired[float]
    r"""Pensions and annuities"""
    taxable_amount: NotRequired[float]
    r"""Taxable amount"""


class PensionsAndAnnuitiesGroup(BaseModel):
    pensions_and_annuities: Annotated[
        Optional[float], pydantic.Field(alias="pensionsAndAnnuities")
    ] = None
    r"""Pensions and annuities"""

    taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="taxableAmount")
    ] = None
    r"""Taxable amount"""


class SocialSecurityBenefitsGroupTypedDict(TypedDict):
    social_security_benefits: NotRequired[float]
    r"""Social security benefits"""
    taxable_amount: NotRequired[float]
    r"""Taxable amount"""


class SocialSecurityBenefitsGroup(BaseModel):
    social_security_benefits: Annotated[
        Optional[float], pydantic.Field(alias="socialSecurityBenefits")
    ] = None
    r"""Social security benefits"""

    taxable_amount: Annotated[
        Optional[float], pydantic.Field(alias="taxableAmount")
    ] = None
    r"""Taxable amount"""


class CapitalGainOrLossGroupTypedDict(TypedDict):
    capital_gain_or_loss: NotRequired[float]
    r"""Capital gain or loss"""
    schedule_d_not_required: NotRequired[bool]
    r"""Whether Schedule D is not required"""


class CapitalGainOrLossGroup(BaseModel):
    capital_gain_or_loss: Annotated[
        Optional[float], pydantic.Field(alias="capitalGainOrLoss")
    ] = None
    r"""Capital gain or loss"""

    schedule_d_not_required: Annotated[
        Optional[bool], pydantic.Field(alias="scheduleDNotRequired")
    ] = None
    r"""Whether Schedule D is not required"""


class AdjustmentsToIncomeGroupTypedDict(TypedDict):
    from_schedule1: NotRequired[float]
    r"""From Schedule 1"""
    charitable_contributions: NotRequired[float]
    r"""Charitable contributions"""
    total_adjustments_to_income: NotRequired[float]
    r"""Total adjustments to income"""


class AdjustmentsToIncomeGroup(BaseModel):
    from_schedule1: Annotated[
        Optional[float], pydantic.Field(alias="fromSchedule1")
    ] = None
    r"""From Schedule 1"""

    charitable_contributions: Annotated[
        Optional[float], pydantic.Field(alias="charitableContributions")
    ] = None
    r"""Charitable contributions"""

    total_adjustments_to_income: Annotated[
        Optional[float], pydantic.Field(alias="totalAdjustmentsToIncome")
    ] = None
    r"""Total adjustments to income"""


class TaxableIncomeGroupTypedDict(TypedDict):
    standard_deduction_or_itemized_deductions: NotRequired[float]
    r"""Standard deduction or itemized deductions"""
    charitable_contributions: NotRequired[float]
    r"""Charitable contributions"""
    partial_sum: NotRequired[float]
    r"""Partial sum"""
    qualified_business_income_deduction: NotRequired[float]
    r"""Qualified business income deduction"""
    total_deduction: NotRequired[float]
    r"""Total deduction"""
    taxable_income: NotRequired[float]
    r"""Taxable income"""


class TaxableIncomeGroup(BaseModel):
    standard_deduction_or_itemized_deductions: Annotated[
        Optional[float], pydantic.Field(alias="standardDeductionOrItemizedDeductions")
    ] = None
    r"""Standard deduction or itemized deductions"""

    charitable_contributions: Annotated[
        Optional[float], pydantic.Field(alias="charitableContributions")
    ] = None
    r"""Charitable contributions"""

    partial_sum: Annotated[Optional[float], pydantic.Field(alias="partialSum")] = None
    r"""Partial sum"""

    qualified_business_income_deduction: Annotated[
        Optional[float], pydantic.Field(alias="qualifiedBusinessIncomeDeduction")
    ] = None
    r"""Qualified business income deduction"""

    total_deduction: Annotated[
        Optional[float], pydantic.Field(alias="totalDeduction")
    ] = None
    r"""Total deduction"""

    taxable_income: Annotated[
        Optional[float], pydantic.Field(alias="taxableIncome")
    ] = None
    r"""Taxable income"""


class TaxGroupTypedDict(TypedDict):
    tax: NotRequired[float]
    r"""Tax"""
    form8814: NotRequired[bool]
    r"""Form 8814"""
    form4972: NotRequired[bool]
    r"""Form 4972"""
    other_form: NotRequired[bool]
    r"""Other form"""
    other_form_name: NotRequired[str]
    r"""Other form name"""
    amount_from_schedule2_check_outdated: NotRequired[bool]
    r"""Amount from Schedule 2 check (outdated)"""
    amount_from_schedule2: NotRequired[float]
    r"""Amount from Schedule 2"""
    group_total: NotRequired[float]
    r"""Group total"""


class TaxGroup(BaseModel):
    tax: Optional[float] = None
    r"""Tax"""

    form8814: Optional[bool] = None
    r"""Form 8814"""

    form4972: Optional[bool] = None
    r"""Form 4972"""

    other_form: Annotated[Optional[bool], pydantic.Field(alias="otherForm")] = None
    r"""Other form"""

    other_form_name: Annotated[Optional[str], pydantic.Field(alias="otherFormName")] = (
        None
    )
    r"""Other form name"""

    amount_from_schedule2_check_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="amountFromSchedule2CheckOutdated")
    ] = None
    r"""Amount from Schedule 2 check (outdated)"""

    amount_from_schedule2: Annotated[
        Optional[float], pydantic.Field(alias="amountFromSchedule2")
    ] = None
    r"""Amount from Schedule 2"""

    group_total: Annotated[Optional[float], pydantic.Field(alias="groupTotal")] = None
    r"""Group total"""


class ChildTaxCreditGroupTypedDict(TypedDict):
    child_tax_credit: NotRequired[float]
    r"""Child tax credit"""
    amount_from_schedule3_check_outdated: NotRequired[bool]
    r"""Amount from Schedule 3 check (outdated)"""
    amount_from_schedule3: NotRequired[float]
    r"""Amount from Schedule 3"""
    group_total: NotRequired[float]
    r"""Group total"""


class ChildTaxCreditGroup(BaseModel):
    child_tax_credit: Annotated[
        Optional[float], pydantic.Field(alias="childTaxCredit")
    ] = None
    r"""Child tax credit"""

    amount_from_schedule3_check_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="amountFromSchedule3CheckOutdated")
    ] = None
    r"""Amount from Schedule 3 check (outdated)"""

    amount_from_schedule3: Annotated[
        Optional[float], pydantic.Field(alias="amountFromSchedule3")
    ] = None
    r"""Amount from Schedule 3"""

    group_total: Annotated[Optional[float], pydantic.Field(alias="groupTotal")] = None
    r"""Group total"""


class FederalIncomeTaxGroupTypedDict(TypedDict):
    form_w2: NotRequired[float]
    r"""Form W-2"""
    form1099: NotRequired[float]
    r"""Form 1099"""
    other_forms: NotRequired[float]
    r"""Other forms"""
    group_total: NotRequired[float]
    r"""Group total"""


class FederalIncomeTaxGroup(BaseModel):
    form_w2: Annotated[Optional[float], pydantic.Field(alias="formW2")] = None
    r"""Form W-2"""

    form1099: Optional[float] = None
    r"""Form 1099"""

    other_forms: Annotated[Optional[float], pydantic.Field(alias="otherForms")] = None
    r"""Other forms"""

    group_total: Annotated[Optional[float], pydantic.Field(alias="groupTotal")] = None
    r"""Group total"""


class EarnedIncomeCreditGroupTypedDict(TypedDict):
    earned_income_credit: NotRequired[float]
    r"""Earned income credit"""
    qualified_to_claim_the_eic: NotRequired[bool]
    r"""Qualified to claim the EIC"""
    combat_pay_election: NotRequired[bool]
    r"""Combat pay election"""
    prior_year_earned_income: NotRequired[float]
    r"""Prior year earned income"""


class EarnedIncomeCreditGroup(BaseModel):
    earned_income_credit: Annotated[
        Optional[float], pydantic.Field(alias="earnedIncomeCredit")
    ] = None
    r"""Earned income credit"""

    qualified_to_claim_the_eic: Annotated[
        Optional[bool], pydantic.Field(alias="qualifiedToClaimTheEic")
    ] = None
    r"""Qualified to claim the EIC"""

    combat_pay_election: Annotated[
        Optional[bool], pydantic.Field(alias="combatPayElection")
    ] = None
    r"""Combat pay election"""

    prior_year_earned_income: Annotated[
        Optional[float], pydantic.Field(alias="priorYearEarnedIncome")
    ] = None
    r"""Prior year earned income"""


class TypeTypedDict(TypedDict):
    r"""Account type"""

    checking: bool
    saving: bool


class Type(BaseModel):
    r"""Account type"""

    checking: bool

    saving: bool


class RefundGroupTypedDict(TypedDict):
    form8888_attached: NotRequired[bool]
    r"""Form 8888 attached"""
    refundable_amount: NotRequired[float]
    r"""Refundable amount/refunded"""
    routing_number: NotRequired[str]
    r"""Routing number"""
    type: NotRequired[TypeTypedDict]
    r"""Account type"""
    account_number: NotRequired[str]
    r"""Account number"""


class RefundGroup(BaseModel):
    form8888_attached: Annotated[
        Optional[bool], pydantic.Field(alias="form8888Attached")
    ] = None
    r"""Form 8888 attached"""

    refundable_amount: Annotated[
        Optional[float], pydantic.Field(alias="refundableAmount")
    ] = None
    r"""Refundable amount/refunded"""

    routing_number: Annotated[Optional[str], pydantic.Field(alias="routingNumber")] = (
        None
    )
    r"""Routing number"""

    type: Optional[Type] = None
    r"""Account type"""

    account_number: Annotated[Optional[str], pydantic.Field(alias="accountNumber")] = (
        None
    )
    r"""Account number"""


class AnotherPersonCanDiscussWithIrsTypedDict(TypedDict):
    r"""Another person can discuss with IRS"""

    no: bool
    yes: bool


class AnotherPersonCanDiscussWithIrs(BaseModel):
    r"""Another person can discuss with IRS"""

    no: bool

    yes: bool


class ThirdPartyDesigneeTypedDict(TypedDict):
    another_person_can_discuss_with_irs: NotRequired[
        AnotherPersonCanDiscussWithIrsTypedDict
    ]
    r"""Another person can discuss with IRS"""
    designees_name: NotRequired[str]
    r"""Designee's name"""
    phone_number: NotRequired[str]
    r"""Phone number"""
    pin: NotRequired[str]
    r"""PIN"""


class ThirdPartyDesignee(BaseModel):
    another_person_can_discuss_with_irs: Annotated[
        Optional[AnotherPersonCanDiscussWithIrs],
        pydantic.Field(alias="anotherPersonCanDiscussWithIrs"),
    ] = None
    r"""Another person can discuss with IRS"""

    designees_name: Annotated[Optional[str], pydantic.Field(alias="designeesName")] = (
        None
    )
    r"""Designee's name"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""Phone number"""

    pin: Optional[str] = None
    r"""PIN"""


class SignatureTypedDict(TypedDict):
    date_: NotRequired[date]
    r"""Date"""
    occupation: NotRequired[str]
    r"""Occupation"""
    identity_protection_pin: NotRequired[str]
    r"""Identity protection PIN"""


class Signature(BaseModel):
    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""Date"""

    occupation: Optional[str] = None
    r"""Occupation"""

    identity_protection_pin: Annotated[
        Optional[str], pydantic.Field(alias="identityProtectionPin")
    ] = None
    r"""Identity protection PIN"""


class SpousesSignatureTypedDict(TypedDict):
    date_: NotRequired[date]
    r"""Date"""
    occupation: NotRequired[str]
    r"""Occupation"""
    identity_protection_pin: NotRequired[str]
    r"""Identity protection PIN"""
    phone_number: NotRequired[str]
    r"""Phone number"""
    email_address: NotRequired[str]
    r"""Email address"""


class SpousesSignature(BaseModel):
    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""Date"""

    occupation: Optional[str] = None
    r"""Occupation"""

    identity_protection_pin: Annotated[
        Optional[str], pydantic.Field(alias="identityProtectionPin")
    ] = None
    r"""Identity protection PIN"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""Phone number"""

    email_address: Annotated[Optional[str], pydantic.Field(alias="emailAddress")] = None
    r"""Email address"""


class PreparerTypedDict(TypedDict):
    preparers_name: NotRequired[str]
    r"""Preparer's name"""
    date_: NotRequired[date]
    r"""Date"""
    ptin: NotRequired[str]
    r"""PTIN"""
    firms_name: NotRequired[str]
    r"""Firm's name"""
    firms_address: NotRequired[str]
    r"""Firm's address"""
    phone_number: NotRequired[str]
    r"""Phone number"""
    firms_ein: NotRequired[str]
    r"""Firm's EIN"""
    third_party_designee_outdated: NotRequired[bool]
    r"""Third party designee (outdated)"""
    self_employed: NotRequired[bool]
    r"""Self-employed"""


class Preparer(BaseModel):
    preparers_name: Annotated[Optional[str], pydantic.Field(alias="preparersName")] = (
        None
    )
    r"""Preparer's name"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""Date"""

    ptin: Optional[str] = None
    r"""PTIN"""

    firms_name: Annotated[Optional[str], pydantic.Field(alias="firmsName")] = None
    r"""Firm's name"""

    firms_address: Annotated[Optional[str], pydantic.Field(alias="firmsAddress")] = None
    r"""Firm's address"""

    phone_number: Annotated[Optional[str], pydantic.Field(alias="phoneNumber")] = None
    r"""Phone number"""

    firms_ein: Annotated[Optional[str], pydantic.Field(alias="firmsEin")] = None
    r"""Firm's EIN"""

    third_party_designee_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="thirdPartyDesigneeOutdated")
    ] = None
    r"""Third party designee (outdated)"""

    self_employed: Annotated[Optional[bool], pydantic.Field(alias="selfEmployed")] = (
        None
    )
    r"""Self-employed"""


class USForm10402018to2022TypedDict(TypedDict):
    r"""A US Form 1040 for 2018 to 2022"""

    form: NotRequired[FormTypedDict]
    r"""Specifies whether the form is 1040 or 1040-SR"""
    year: NotRequired[str]
    r"""Indicates the year of the form"""
    filing_status: NotRequired[FilingStatusTypedDict]
    r"""The taxpayer's filing status"""
    mfs_spouse_or_hoh_or_qw_child_name: NotRequired[str]
    r"""The name of the taxpayer's spouse or child"""
    first_name: NotRequired[str]
    r"""The taxpayer's first name"""
    last_name: NotRequired[str]
    r"""The taxpayer's last name"""
    ssn: NotRequired[str]
    r"""The taxpayer's social security number"""
    spouse: NotRequired[SpouseTypedDict]
    address: NotRequired[AddressTypedDict]
    full_year_health_care_coverage_outdated: NotRequired[bool]
    r"""Indicates whether the taxpayer has health insurance coverage (outdated)"""
    presidential_election_campaign: NotRequired[PresidentialElectionCampaignTypedDict]
    financial_interest_in_virtual_currency_during_this_year: NotRequired[
        FinancialInterestInVirtualCurrencyDuringThisYearTypedDict
    ]
    r"""Indicates whether there was any income related to virtual currencies"""
    standard_deduction: NotRequired[StandardDeductionTypedDict]
    more_than_four_dependents: NotRequired[bool]
    r"""Indicated whether the taxpayer has more than four dependents"""
    dependents: NotRequired[List[DependentsTypedDict]]
    wages_salaries_tips: NotRequired[float]
    r"""Wages, salaries, tips"""
    tax_exempt_interest_group: NotRequired[TaxExemptInterestGroupTypedDict]
    dividends_group: NotRequired[DividendsGroupTypedDict]
    iras_pensions_and_annuities_group_outdated: NotRequired[
        IrasPensionsAndAnnuitiesGroupOutdatedTypedDict
    ]
    ira_distributions_group: NotRequired[IraDistributionsGroupTypedDict]
    pensions_and_annuities_group: NotRequired[PensionsAndAnnuitiesGroupTypedDict]
    social_security_benefits_group: NotRequired[SocialSecurityBenefitsGroupTypedDict]
    capital_gain_or_loss_group: NotRequired[CapitalGainOrLossGroupTypedDict]
    amount_from_schedule1_line22_outdated: NotRequired[float]
    r"""Amount from Schedule 1 line 22 (outdated)"""
    other_income_from_schedule1: NotRequired[float]
    r"""Other income from Schedule 1"""
    total_income: NotRequired[float]
    r"""Total income"""
    adjustments_to_income_group: NotRequired[AdjustmentsToIncomeGroupTypedDict]
    adjusted_gross_income: NotRequired[float]
    r"""Adjusted gross income"""
    taxable_income_group: NotRequired[TaxableIncomeGroupTypedDict]
    tax_group: NotRequired[TaxGroupTypedDict]
    child_tax_credit_group: NotRequired[ChildTaxCreditGroupTypedDict]
    tax_minus_child_tax_credit: NotRequired[float]
    r"""Tax minus child tax credit"""
    other_taxes_including_self_employment_tax: NotRequired[float]
    r"""Other taxes including self-employment tax"""
    total_tax: NotRequired[float]
    r"""Total tax"""
    federal_income_tax_withheld_from_forms_w2_and1099_outdated: NotRequired[float]
    r"""Federal income tax withheld from Forms W-2 and 1099 (outdated)"""
    federal_income_tax_group: NotRequired[FederalIncomeTaxGroupTypedDict]
    this_year_estimated_tax_payments_and_amount_applied_from_last_year_return: (
        NotRequired[float]
    )
    r"""This year estimated tax payments and amount applied from last year return"""
    earned_income_credit_group: NotRequired[EarnedIncomeCreditGroupTypedDict]
    additional_child_tax_credit_schedule8812: NotRequired[float]
    r"""Additional child tax credit"""
    american_opportunity_credit_from_form8863: NotRequired[float]
    r"""American opportunity credit from Form 8863"""
    recovery_rebate_credit: NotRequired[float]
    r"""Recovery rebate credit"""
    amount_from_schedule5: NotRequired[float]
    r"""Amount from Schedule 5"""
    amount_from_schedule3: NotRequired[float]
    r"""Amount from Schedule 3"""
    total_other_payments_and_refundable_credits: NotRequired[float]
    r"""Total other payments and refundable credits"""
    total_payments: NotRequired[float]
    r"""Total payments"""
    overpaid_amount: NotRequired[float]
    r"""Overpaid amount"""
    refund_group: NotRequired[RefundGroupTypedDict]
    overpaid_amount_to_be_applied_to_next_year_estimated_tax: NotRequired[float]
    r"""Overpaid amount to be applied to next year estimated tax"""
    owed_amount: NotRequired[float]
    r"""Owed amount"""
    estimated_tax_penalty: NotRequired[float]
    r"""Estimated tax penalty"""
    third_party_designee: NotRequired[ThirdPartyDesigneeTypedDict]
    signature: NotRequired[SignatureTypedDict]
    spouses_signature: NotRequired[SpousesSignatureTypedDict]
    preparer: NotRequired[PreparerTypedDict]


class USForm10402018to2022(BaseModel):
    r"""A US Form 1040 for 2018 to 2022"""

    form: Optional[Form] = None
    r"""Specifies whether the form is 1040 or 1040-SR"""

    year: Optional[str] = None
    r"""Indicates the year of the form"""

    filing_status: Annotated[
        Optional[FilingStatus], pydantic.Field(alias="filingStatus")
    ] = None
    r"""The taxpayer's filing status"""

    mfs_spouse_or_hoh_or_qw_child_name: Annotated[
        Optional[str], pydantic.Field(alias="mfsSpouseOrHohOrQwChildName")
    ] = None
    r"""The name of the taxpayer's spouse or child"""

    first_name: Annotated[Optional[str], pydantic.Field(alias="firstName")] = None
    r"""The taxpayer's first name"""

    last_name: Annotated[Optional[str], pydantic.Field(alias="lastName")] = None
    r"""The taxpayer's last name"""

    ssn: Optional[str] = None
    r"""The taxpayer's social security number"""

    spouse: Optional[Spouse] = None

    address: Optional[Address] = None

    full_year_health_care_coverage_outdated: Annotated[
        Optional[bool], pydantic.Field(alias="fullYearHealthCareCoverageOutdated")
    ] = None
    r"""Indicates whether the taxpayer has health insurance coverage (outdated)"""

    presidential_election_campaign: Annotated[
        Optional[PresidentialElectionCampaign],
        pydantic.Field(alias="presidentialElectionCampaign"),
    ] = None

    financial_interest_in_virtual_currency_during_this_year: Annotated[
        Optional[FinancialInterestInVirtualCurrencyDuringThisYear],
        pydantic.Field(alias="financialInterestInVirtualCurrencyDuringThisYear"),
    ] = None
    r"""Indicates whether there was any income related to virtual currencies"""

    standard_deduction: Annotated[
        Optional[StandardDeduction], pydantic.Field(alias="standardDeduction")
    ] = None

    more_than_four_dependents: Annotated[
        Optional[bool], pydantic.Field(alias="moreThanFourDependents")
    ] = None
    r"""Indicated whether the taxpayer has more than four dependents"""

    dependents: Optional[List[Dependents]] = None

    wages_salaries_tips: Annotated[
        Optional[float], pydantic.Field(alias="wagesSalariesTips")
    ] = None
    r"""Wages, salaries, tips"""

    tax_exempt_interest_group: Annotated[
        Optional[TaxExemptInterestGroup], pydantic.Field(alias="taxExemptInterestGroup")
    ] = None

    dividends_group: Annotated[
        Optional[DividendsGroup], pydantic.Field(alias="dividendsGroup")
    ] = None

    iras_pensions_and_annuities_group_outdated: Annotated[
        Optional[IrasPensionsAndAnnuitiesGroupOutdated],
        pydantic.Field(alias="irasPensionsAndAnnuitiesGroupOutdated"),
    ] = None

    ira_distributions_group: Annotated[
        Optional[IraDistributionsGroup], pydantic.Field(alias="iraDistributionsGroup")
    ] = None

    pensions_and_annuities_group: Annotated[
        Optional[PensionsAndAnnuitiesGroup],
        pydantic.Field(alias="pensionsAndAnnuitiesGroup"),
    ] = None

    social_security_benefits_group: Annotated[
        Optional[SocialSecurityBenefitsGroup],
        pydantic.Field(alias="socialSecurityBenefitsGroup"),
    ] = None

    capital_gain_or_loss_group: Annotated[
        Optional[CapitalGainOrLossGroup], pydantic.Field(alias="capitalGainOrLossGroup")
    ] = None

    amount_from_schedule1_line22_outdated: Annotated[
        Optional[float], pydantic.Field(alias="amountFromSchedule1Line22Outdated")
    ] = None
    r"""Amount from Schedule 1 line 22 (outdated)"""

    other_income_from_schedule1: Annotated[
        Optional[float], pydantic.Field(alias="otherIncomeFromSchedule1")
    ] = None
    r"""Other income from Schedule 1"""

    total_income: Annotated[Optional[float], pydantic.Field(alias="totalIncome")] = None
    r"""Total income"""

    adjustments_to_income_group: Annotated[
        Optional[AdjustmentsToIncomeGroup],
        pydantic.Field(alias="adjustmentsToIncomeGroup"),
    ] = None

    adjusted_gross_income: Annotated[
        Optional[float], pydantic.Field(alias="adjustedGrossIncome")
    ] = None
    r"""Adjusted gross income"""

    taxable_income_group: Annotated[
        Optional[TaxableIncomeGroup], pydantic.Field(alias="taxableIncomeGroup")
    ] = None

    tax_group: Annotated[Optional[TaxGroup], pydantic.Field(alias="taxGroup")] = None

    child_tax_credit_group: Annotated[
        Optional[ChildTaxCreditGroup], pydantic.Field(alias="childTaxCreditGroup")
    ] = None

    tax_minus_child_tax_credit: Annotated[
        Optional[float], pydantic.Field(alias="taxMinusChildTaxCredit")
    ] = None
    r"""Tax minus child tax credit"""

    other_taxes_including_self_employment_tax: Annotated[
        Optional[float], pydantic.Field(alias="otherTaxesIncludingSelfEmploymentTax")
    ] = None
    r"""Other taxes including self-employment tax"""

    total_tax: Annotated[Optional[float], pydantic.Field(alias="totalTax")] = None
    r"""Total tax"""

    federal_income_tax_withheld_from_forms_w2_and1099_outdated: Annotated[
        Optional[float],
        pydantic.Field(alias="federalIncomeTaxWithheldFromFormsW2And1099Outdated"),
    ] = None
    r"""Federal income tax withheld from Forms W-2 and 1099 (outdated)"""

    federal_income_tax_group: Annotated[
        Optional[FederalIncomeTaxGroup], pydantic.Field(alias="federalIncomeTaxGroup")
    ] = None

    this_year_estimated_tax_payments_and_amount_applied_from_last_year_return: Annotated[
        Optional[float],
        pydantic.Field(
            alias="thisYearEstimatedTaxPaymentsAndAmountAppliedFromLastYearReturn"
        ),
    ] = None
    r"""This year estimated tax payments and amount applied from last year return"""

    earned_income_credit_group: Annotated[
        Optional[EarnedIncomeCreditGroup],
        pydantic.Field(alias="earnedIncomeCreditGroup"),
    ] = None

    additional_child_tax_credit_schedule8812: Annotated[
        Optional[float], pydantic.Field(alias="additionalChildTaxCreditSchedule8812")
    ] = None
    r"""Additional child tax credit"""

    american_opportunity_credit_from_form8863: Annotated[
        Optional[float], pydantic.Field(alias="americanOpportunityCreditFromForm8863")
    ] = None
    r"""American opportunity credit from Form 8863"""

    recovery_rebate_credit: Annotated[
        Optional[float], pydantic.Field(alias="recoveryRebateCredit")
    ] = None
    r"""Recovery rebate credit"""

    amount_from_schedule5: Annotated[
        Optional[float], pydantic.Field(alias="amountFromSchedule5")
    ] = None
    r"""Amount from Schedule 5"""

    amount_from_schedule3: Annotated[
        Optional[float], pydantic.Field(alias="amountFromSchedule3")
    ] = None
    r"""Amount from Schedule 3"""

    total_other_payments_and_refundable_credits: Annotated[
        Optional[float], pydantic.Field(alias="totalOtherPaymentsAndRefundableCredits")
    ] = None
    r"""Total other payments and refundable credits"""

    total_payments: Annotated[
        Optional[float], pydantic.Field(alias="totalPayments")
    ] = None
    r"""Total payments"""

    overpaid_amount: Annotated[
        Optional[float], pydantic.Field(alias="overpaidAmount")
    ] = None
    r"""Overpaid amount"""

    refund_group: Annotated[
        Optional[RefundGroup], pydantic.Field(alias="refundGroup")
    ] = None

    overpaid_amount_to_be_applied_to_next_year_estimated_tax: Annotated[
        Optional[float],
        pydantic.Field(alias="overpaidAmountToBeAppliedToNextYearEstimatedTax"),
    ] = None
    r"""Overpaid amount to be applied to next year estimated tax"""

    owed_amount: Annotated[Optional[float], pydantic.Field(alias="owedAmount")] = None
    r"""Owed amount"""

    estimated_tax_penalty: Annotated[
        Optional[float], pydantic.Field(alias="estimatedTaxPenalty")
    ] = None
    r"""Estimated tax penalty"""

    third_party_designee: Annotated[
        Optional[ThirdPartyDesignee], pydantic.Field(alias="thirdPartyDesignee")
    ] = None

    signature: Optional[Signature] = None

    spouses_signature: Annotated[
        Optional[SpousesSignature], pydantic.Field(alias="spousesSignature")
    ] = None

    preparer: Optional[Preparer] = None


USForm1040FieldsTypedDict = TypeAliasType(
    "USForm1040FieldsTypedDict",
    Union[USForm10402018to2022TypedDict, USForm10402022TypedDict],
)
r"""Fields extracted from a US Form 1040"""


USForm1040Fields = TypeAliasType(
    "USForm1040Fields", Union[USForm10402018to2022, USForm10402022]
)
r"""Fields extracted from a US Form 1040"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai import utils
from abbyy_document_ai.types import BaseModel
from typing import Optional


class PaymentRequiredErrorData(BaseModel):
    type: str
    r"""A URI reference that identifies the problem type."""

    title: str
    r"""A short, human-readable summary of the problem type."""

    status: float
    r"""The HTTP status code generated by the origin server for this occurrence of the problem."""

    detail: str
    r"""A human-readable explanation specific to this occurrence of the problem."""

    instance: Optional[str] = None
    r"""The URI that identifies the specific occurrence of the problem."""


class PaymentRequiredError(Exception):
    r"""The error returned when request limits have been reached."""

    data: PaymentRequiredErrorData

    def __init__(self, data: PaymentRequiredErrorData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, PaymentRequiredErrorData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PersonalEarningsStatementFieldsTypedDict(TypedDict):
    r"""Fields extracted from a personal earnings statement"""

    employee_name: NotRequired[str]
    r"""The employee's name"""
    employee_address: NotRequired[str]
    r"""The employee's address"""
    employer_identification_number: NotRequired[str]
    r"""The employer's identification number"""
    ssn: NotRequired[str]
    r"""The employee's Social Security Number"""
    employer_name: NotRequired[str]
    r"""The name of the employing organization"""
    employer_address: NotRequired[str]
    r"""The address of the employing organization"""
    reporting_period_start_date: NotRequired[date]
    r"""The start date of the reporting period"""
    reporting_period_end_date: NotRequired[date]
    r"""The end date of the reporting period"""
    pay_date: NotRequired[date]
    r"""The date of payment"""
    pay_rate: NotRequired[float]
    r"""The amount of salary paid for a unit of working time or for volume of work"""
    current_period_gross_pay: NotRequired[float]
    r"""The employee's total gross pay for the reporting period"""
    year_to_date_gross_pay: NotRequired[float]
    r"""The employee's total year-to-date gross pay"""
    current_period_total_deductions: NotRequired[float]
    r"""The total amount deducted from the salary (excluding taxes) for the reporting period"""
    current_period_total_taxes: NotRequired[float]
    r"""The total amount of tax withheld from the salary for the reporting period"""
    current_period_net_pay: NotRequired[float]
    r"""The employee's total net pay for the reporting period"""
    year_to_date_total_deductions: NotRequired[float]
    r"""The total amount deducted from the salary (excluding taxes) year-to-date"""
    year_to_date_total_taxes: NotRequired[float]
    r"""The total amount of tax withheld from the salary year-to-date"""
    year_to_date_net_pay: NotRequired[float]
    r"""The employee's total year-to-date net pay"""


class PersonalEarningsStatementFields(BaseModel):
    r"""Fields extracted from a personal earnings statement"""

    employee_name: Annotated[Optional[str], pydantic.Field(alias="employeeName")] = None
    r"""The employee's name"""

    employee_address: Annotated[
        Optional[str], pydantic.Field(alias="employeeAddress")
    ] = None
    r"""The employee's address"""

    employer_identification_number: Annotated[
        Optional[str], pydantic.Field(alias="employerIdentificationNumber")
    ] = None
    r"""The employer's identification number"""

    ssn: Optional[str] = None
    r"""The employee's Social Security Number"""

    employer_name: Annotated[Optional[str], pydantic.Field(alias="employerName")] = None
    r"""The name of the employing organization"""

    employer_address: Annotated[
        Optional[str], pydantic.Field(alias="employerAddress")
    ] = None
    r"""The address of the employing organization"""

    reporting_period_start_date: Annotated[
        Optional[date], pydantic.Field(alias="reportingPeriodStartDate")
    ] = None
    r"""The start date of the reporting period"""

    reporting_period_end_date: Annotated[
        Optional[date], pydantic.Field(alias="reportingPeriodEndDate")
    ] = None
    r"""The end date of the reporting period"""

    pay_date: Annotated[Optional[date], pydantic.Field(alias="payDate")] = None
    r"""The date of payment"""

    pay_rate: Annotated[Optional[float], pydantic.Field(alias="payRate")] = None
    r"""The amount of salary paid for a unit of working time or for volume of work"""

    current_period_gross_pay: Annotated[
        Optional[float], pydantic.Field(alias="currentPeriodGrossPay")
    ] = None
    r"""The employee's total gross pay for the reporting period"""

    year_to_date_gross_pay: Annotated[
        Optional[float], pydantic.Field(alias="yearToDateGrossPay")
    ] = None
    r"""The employee's total year-to-date gross pay"""

    current_period_total_deductions: Annotated[
        Optional[float], pydantic.Field(alias="currentPeriodTotalDeductions")
    ] = None
    r"""The total amount deducted from the salary (excluding taxes) for the reporting period"""

    current_period_total_taxes: Annotated[
        Optional[float], pydantic.Field(alias="currentPeriodTotalTaxes")
    ] = None
    r"""The total amount of tax withheld from the salary for the reporting period"""

    current_period_net_pay: Annotated[
        Optional[float], pydantic.Field(alias="currentPeriodNetPay")
    ] = None
    r"""The employee's total net pay for the reporting period"""

    year_to_date_total_deductions: Annotated[
        Optional[float], pydantic.Field(alias="yearToDateTotalDeductions")
    ] = None
    r"""The total amount deducted from the salary (excluding taxes) year-to-date"""

    year_to_date_total_taxes: Annotated[
        Optional[float], pydantic.Field(alias="yearToDateTotalTaxes")
    ] = None
    r"""The total amount of tax withheld from the salary year-to-date"""

    year_to_date_net_pay: Annotated[
        Optional[float], pydantic.Field(alias="yearToDateNetPay")
    ] = None
    r"""The employee's total year-to-date net pay"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from abbyy_document_ai.types import BaseModel
from abbyy_document_ai.utils import FieldMetadata, QueryParamMetadata
import pydantic
from typing import Callable, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListDocumentsRequestTypedDict(TypedDict):
    cursor: NotRequired[str]
    r"""The cursor to start the list from. If not provided, the list will start from the most recent documents."""
    limit: NotRequired[int]
    r"""The number of documents to return. The maximum allowed value is 25. If not provided, the list will return up to 10 documents."""


class ListDocumentsRequest(BaseModel):
    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The cursor to start the list from. If not provided, the list will start from the most recent documents."""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10
    r"""The number of documents to return. The maximum allowed value is 25. If not provided, the list will return up to 10 documents."""


class ListDocumentsResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    headers: Dict[str, List[str]]
    documents: NotRequired[List[DocumentTypedDict]]
    r"""Default Response"""


class ListDocumentsResponse(BaseModel):
    next: Callable[[], Optional[ListDocumentsResponse]]

    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    headers: Dict[str, List[str]]

    documents: Optional[List[Document]] = None
    r"""Default Response"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .airwaybillfields import AirWaybillFields, AirWaybillFieldsTypedDict
from .document import Document, DocumentTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AirWaybillValidationErrorsTypedDict(TypedDict):
    message: str


class AirWaybillValidationErrors(BaseModel):
    message: str


class AirWaybillTypedDict(TypedDict):
    r"""Extracted Air Waybill Data Response"""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""
    fields: NotRequired[AirWaybillFieldsTypedDict]
    r"""Fields extracted from an air waybill"""
    validation_errors: NotRequired[List[AirWaybillValidationErrorsTypedDict]]
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""


class AirWaybill(BaseModel):
    r"""Extracted Air Waybill Data Response"""

    meta: Document
    r"""Represents a document that has been submitted for processing."""

    fields: Optional[AirWaybillFields] = None
    r"""Fields extracted from an air waybill"""

    validation_errors: Annotated[
        Optional[List[AirWaybillValidationErrors]],
        pydantic.Field(alias="validationErrors"),
    ] = None
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .taxireceiptfields import TaxiReceiptFields, TaxiReceiptFieldsTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TaxiReceiptValidationErrorsTypedDict(TypedDict):
    message: str


class TaxiReceiptValidationErrors(BaseModel):
    message: str


class TaxiReceiptTypedDict(TypedDict):
    r"""Extracted Taxi Receipt Data Response"""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""
    fields: NotRequired[TaxiReceiptFieldsTypedDict]
    r"""Fields extracted from a taxi receipt"""
    validation_errors: NotRequired[List[TaxiReceiptValidationErrorsTypedDict]]
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""


class TaxiReceipt(BaseModel):
    r"""Extracted Taxi Receipt Data Response"""

    meta: Document
    r"""Represents a document that has been submitted for processing."""

    fields: Optional[TaxiReceiptFields] = None
    r"""Fields extracted from a taxi receipt"""

    validation_errors: Annotated[
        Optional[List[TaxiReceiptValidationErrors]],
        pydantic.Field(alias="validationErrors"),
    ] = None
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from abbyy_document_ai.airwaybill_sdk import AirWaybillSDK
from abbyy_document_ai.arrivalnotice_sdk import ArrivalNoticeSDK
from abbyy_document_ai.bankstatement_sdk import BankStatementSDK
from abbyy_document_ai.basiccontract_sdk import BasicContractSDK
from abbyy_document_ai.billoflading_sdk import BillOfLadingSDK
from abbyy_document_ai.brokeragestatement_sdk import BrokerageStatementSDK
from abbyy_document_ai.certificateoforigin_sdk import CertificateOfOriginSDK
from abbyy_document_ai.commercialinvoice_sdk import CommercialInvoiceSDK
from abbyy_document_ai.customsdeclaration_sdk import CustomsDeclarationSDK
from abbyy_document_ai.dangerousgoodsdeclaration_sdk import DangerousGoodsDeclarationSDK
from abbyy_document_ai.deliverynote_sdk import DeliveryNoteSDK
from abbyy_document_ai.documentconversion import DocumentConversion
from abbyy_document_ai.hotelinvoice_sdk import HotelInvoiceSDK
from abbyy_document_ai.imagetotext import ImageToText
from abbyy_document_ai.internationalconsignmentnote_sdk import (
    InternationalConsignmentNoteSDK,
)
from abbyy_document_ai.invoice_sdk import InvoiceSDK
from abbyy_document_ai.packinglist_sdk import PackingListSDK
from abbyy_document_ai.personalearningsstatement_sdk import PersonalEarningsStatementSDK
from abbyy_document_ai.purchaseorder_sdk import PurchaseOrderSDK
from abbyy_document_ai.receipt_sdk import ReceiptSDK
from abbyy_document_ai.remittanceadvice_sdk import RemittanceAdviceSDK
from abbyy_document_ai.seawaybill_sdk import SeaWaybillSDK
from abbyy_document_ai.taxireceipt_sdk import TaxiReceiptSDK
from abbyy_document_ai.usform1040_sdk import UsForm1040SDK
from abbyy_document_ai.usformw2_sdk import UsFormW2SDK
from abbyy_document_ai.utilitybill_sdk import UtilityBillSDK


class Models(BaseSDK):
    document_conversion: DocumentConversion
    image_to_text: ImageToText
    receipt: ReceiptSDK
    invoice: InvoiceSDK
    purchase_order: PurchaseOrderSDK
    remittance_advice: RemittanceAdviceSDK
    delivery_note: DeliveryNoteSDK
    hotel_invoice: HotelInvoiceSDK
    taxi_receipt: TaxiReceiptSDK
    utility_bill: UtilityBillSDK
    us_form1040: UsForm1040SDK
    us_form_w2: UsFormW2SDK
    personal_earnings_statement: PersonalEarningsStatementSDK
    bank_statement: BankStatementSDK
    air_waybill: AirWaybillSDK
    arrival_notice: ArrivalNoticeSDK
    bill_of_lading: BillOfLadingSDK
    certificate_of_origin: CertificateOfOriginSDK
    commercial_invoice: CommercialInvoiceSDK
    dangerous_goods_declaration: DangerousGoodsDeclarationSDK
    customs_declaration: CustomsDeclarationSDK
    packing_list: PackingListSDK
    sea_waybill: SeaWaybillSDK
    international_consignment_note: InternationalConsignmentNoteSDK
    basic_contract: BasicContractSDK
    brokerage_statement: BrokerageStatementSDK

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.document_conversion = DocumentConversion(self.sdk_configuration)
        self.image_to_text = ImageToText(self.sdk_configuration)
        self.receipt = ReceiptSDK(self.sdk_configuration)
        self.invoice = InvoiceSDK(self.sdk_configuration)
        self.purchase_order = PurchaseOrderSDK(self.sdk_configuration)
        self.remittance_advice = RemittanceAdviceSDK(self.sdk_configuration)
        self.delivery_note = DeliveryNoteSDK(self.sdk_configuration)
        self.hotel_invoice = HotelInvoiceSDK(self.sdk_configuration)
        self.taxi_receipt = TaxiReceiptSDK(self.sdk_configuration)
        self.utility_bill = UtilityBillSDK(self.sdk_configuration)
        self.us_form1040 = UsForm1040SDK(self.sdk_configuration)
        self.us_form_w2 = UsFormW2SDK(self.sdk_configuration)
        self.personal_earnings_statement = PersonalEarningsStatementSDK(
            self.sdk_configuration
        )
        self.bank_statement = BankStatementSDK(self.sdk_configuration)
        self.air_waybill = AirWaybillSDK(self.sdk_configuration)
        self.arrival_notice = ArrivalNoticeSDK(self.sdk_configuration)
        self.bill_of_lading = BillOfLadingSDK(self.sdk_configuration)
        self.certificate_of_origin = CertificateOfOriginSDK(self.sdk_configuration)
        self.commercial_invoice = CommercialInvoiceSDK(self.sdk_configuration)
        self.dangerous_goods_declaration = DangerousGoodsDeclarationSDK(
            self.sdk_configuration
        )
        self.customs_declaration = CustomsDeclarationSDK(self.sdk_configuration)
        self.packing_list = PackingListSDK(self.sdk_configuration)
        self.sea_waybill = SeaWaybillSDK(self.sdk_configuration)
        self.international_consignment_note = InternationalConsignmentNoteSDK(
            self.sdk_configuration
        )
        self.basic_contract = BasicContractSDK(self.sdk_configuration)
        self.brokerage_statement = BrokerageStatementSDK(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hotelinvoice import HotelInvoice, HotelInvoiceTypedDict
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from abbyy_document_ai.types import BaseModel
from abbyy_document_ai.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetExtractedHotelInvoiceFieldsRequestTypedDict(TypedDict):
    document_id: str
    r"""The id of the document"""


class GetExtractedHotelInvoiceFieldsRequest(BaseModel):
    document_id: Annotated[
        str,
        pydantic.Field(alias="documentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The id of the document"""


class GetExtractedHotelInvoiceFieldsResponseTypedDict(TypedDict):
    http_meta: HTTPMetadataTypedDict
    hotel_invoice: NotRequired[HotelInvoiceTypedDict]
    r"""Extracted Hotel Invoice Data Response"""


class GetExtractedHotelInvoiceFieldsResponse(BaseModel):
    http_meta: Annotated[Optional[HTTPMetadata], pydantic.Field(exclude=True)] = None

    hotel_invoice: Optional[HotelInvoice] = None
    r"""Extracted Hotel Invoice Data Response"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from .receiptfields import ReceiptFields, ReceiptFieldsTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ValidationErrorsTypedDict(TypedDict):
    message: str


class ValidationErrors(BaseModel):
    message: str


class ReceiptTypedDict(TypedDict):
    r"""Extracted Receipt Data Response"""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""
    fields: NotRequired[ReceiptFieldsTypedDict]
    r"""Fields extracted from a receipt"""
    validation_errors: NotRequired[List[ValidationErrorsTypedDict]]
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""


class Receipt(BaseModel):
    r"""Extracted Receipt Data Response"""

    meta: Document
    r"""Represents a document that has been submitted for processing."""

    fields: Optional[ReceiptFields] = None
    r"""Fields extracted from a receipt"""

    validation_errors: Annotated[
        Optional[List[ValidationErrors]], pydantic.Field(alias="validationErrors")
    ] = None
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class InternationalConsignmentNoteFieldsShipperTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The shipper's name"""
    address: NotRequired[str]
    r"""The shipper's address"""
    country: NotRequired[str]
    r"""The shipper's country"""
    state_or_province: NotRequired[str]
    r"""The shipper's state or province"""
    city: NotRequired[str]
    r"""The shipper's city"""
    postal_code: NotRequired[str]
    r"""The shipper's postal code"""
    street: NotRequired[str]
    r"""The shipper's street address"""
    signature_and_stamp: NotRequired[str]
    r"""The shipper's signature and stamp"""


class InternationalConsignmentNoteFieldsShipper(BaseModel):
    name: Optional[str] = None
    r"""The shipper's name"""

    address: Optional[str] = None
    r"""The shipper's address"""

    country: Optional[str] = None
    r"""The shipper's country"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The shipper's state or province"""

    city: Optional[str] = None
    r"""The shipper's city"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The shipper's postal code"""

    street: Optional[str] = None
    r"""The shipper's street address"""

    signature_and_stamp: Annotated[
        Optional[str], pydantic.Field(alias="signatureAndStamp")
    ] = None
    r"""The shipper's signature and stamp"""


class InternationalConsignmentNoteFieldsConsigneeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The consignee's name"""
    address: NotRequired[str]
    r"""The consignee's address"""
    country: NotRequired[str]
    r"""The consignee's country"""
    state_or_province: NotRequired[str]
    r"""The consignee's state or province"""
    city: NotRequired[str]
    r"""The consignee's city"""
    postal_code: NotRequired[str]
    r"""The consignee's postal code"""
    street: NotRequired[str]
    r"""The consignee's street address"""
    signature_and_stamp: NotRequired[str]
    r"""The consignee's signature and stamp"""


class InternationalConsignmentNoteFieldsConsignee(BaseModel):
    name: Optional[str] = None
    r"""The consignee's name"""

    address: Optional[str] = None
    r"""The consignee's address"""

    country: Optional[str] = None
    r"""The consignee's country"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The consignee's state or province"""

    city: Optional[str] = None
    r"""The consignee's city"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The consignee's postal code"""

    street: Optional[str] = None
    r"""The consignee's street address"""

    signature_and_stamp: Annotated[
        Optional[str], pydantic.Field(alias="signatureAndStamp")
    ] = None
    r"""The consignee's signature and stamp"""


class InternationalConsignmentNoteFieldsCarrierTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The carrier's name"""
    address: NotRequired[str]
    r"""The carrier's address"""
    country: NotRequired[str]
    r"""The carrier's country"""
    state_or_province: NotRequired[str]
    r"""The carrier's state or province"""
    city: NotRequired[str]
    r"""The carrier's city"""
    postal_code: NotRequired[str]
    r"""The carrier's postal code"""
    street: NotRequired[str]
    r"""The carrier's street address"""
    signature_and_stamp: NotRequired[str]
    r"""The carrier's signature and stamp"""


class InternationalConsignmentNoteFieldsCarrier(BaseModel):
    name: Optional[str] = None
    r"""The carrier's name"""

    address: Optional[str] = None
    r"""The carrier's address"""

    country: Optional[str] = None
    r"""The carrier's country"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The carrier's state or province"""

    city: Optional[str] = None
    r"""The carrier's city"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The carrier's postal code"""

    street: Optional[str] = None
    r"""The carrier's street address"""

    signature_and_stamp: Annotated[
        Optional[str], pydantic.Field(alias="signatureAndStamp")
    ] = None
    r"""The carrier's signature and stamp"""


class SuccessiveCarrierTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The successive carrier's name"""
    address: NotRequired[str]
    r"""The successive carrier's address"""
    country: NotRequired[str]
    r"""The successive carrier's country"""
    state_or_province: NotRequired[str]
    r"""The successive carrier's state or province"""
    city: NotRequired[str]
    r"""The successive carrier's city"""
    postal_code: NotRequired[str]
    r"""The successive carrier's postal code"""
    street: NotRequired[str]
    r"""The successive carrier's street address"""


class SuccessiveCarrier(BaseModel):
    name: Optional[str] = None
    r"""The successive carrier's name"""

    address: Optional[str] = None
    r"""The successive carrier's address"""

    country: Optional[str] = None
    r"""The successive carrier's country"""

    state_or_province: Annotated[
        Optional[str], pydantic.Field(alias="stateOrProvince")
    ] = None
    r"""The successive carrier's state or province"""

    city: Optional[str] = None
    r"""The successive carrier's city"""

    postal_code: Annotated[Optional[str], pydantic.Field(alias="postalCode")] = None
    r"""The successive carrier's postal code"""

    street: Optional[str] = None
    r"""The successive carrier's street address"""


class PlaceOfDeliveryOfGoodsTypedDict(TypedDict):
    address: NotRequired[str]
    r"""The delivery location address"""
    country: NotRequired[str]
    r"""The delivery location country"""


class PlaceOfDeliveryOfGoods(BaseModel):
    address: Optional[str] = None
    r"""The delivery location address"""

    country: Optional[str] = None
    r"""The delivery location country"""


class PlaceAndDateOfTakingOverOfGoodsTypedDict(TypedDict):
    address: NotRequired[str]
    r"""The loading location address"""
    country: NotRequired[str]
    r"""The loading location country"""
    date_: NotRequired[date]
    r"""The date of loading"""


class PlaceAndDateOfTakingOverOfGoods(BaseModel):
    address: Optional[str] = None
    r"""The loading location address"""

    country: Optional[str] = None
    r"""The loading location country"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""The date of loading"""


class InternationalConsignmentNoteFieldsLineItemsTypedDict(TypedDict):
    marks_and_numbers: NotRequired[str]
    r"""Special numbering and marking on the packaging"""
    number_of_packages: NotRequired[float]
    r"""The number of packages of the goods"""
    type_of_packaging: NotRequired[str]
    r"""The package type"""
    nature_of_goods: NotRequired[str]
    r"""The name of the types of goods"""
    hs_code: NotRequired[str]
    r"""The HS code of the goods"""
    gross_weight: NotRequired[float]
    r"""The gross weight of the goods"""
    weight_uom: NotRequired[str]
    r"""The unit of measurement used for the weight"""
    volume: NotRequired[float]
    r"""The volume of the goods"""
    volume_uom: NotRequired[str]
    r"""The unit of measurement used for the volume"""


class InternationalConsignmentNoteFieldsLineItems(BaseModel):
    marks_and_numbers: Annotated[
        Optional[str], pydantic.Field(alias="marksAndNumbers")
    ] = None
    r"""Special numbering and marking on the packaging"""

    number_of_packages: Annotated[
        Optional[float], pydantic.Field(alias="numberOfPackages")
    ] = None
    r"""The number of packages of the goods"""

    type_of_packaging: Annotated[
        Optional[str], pydantic.Field(alias="typeOfPackaging")
    ] = None
    r"""The package type"""

    nature_of_goods: Annotated[Optional[str], pydantic.Field(alias="natureOfGoods")] = (
        None
    )
    r"""The name of the types of goods"""

    hs_code: Annotated[Optional[str], pydantic.Field(alias="hsCode")] = None
    r"""The HS code of the goods"""

    gross_weight: Annotated[Optional[float], pydantic.Field(alias="grossWeight")] = None
    r"""The gross weight of the goods"""

    weight_uom: Annotated[Optional[str], pydantic.Field(alias="weightUom")] = None
    r"""The unit of measurement used for the weight"""

    volume: Optional[float] = None
    r"""The volume of the goods"""

    volume_uom: Annotated[Optional[str], pydantic.Field(alias="volumeUom")] = None
    r"""The unit of measurement used for the volume"""


class InternationalConsignmentNoteFieldsTotalsTypedDict(TypedDict):
    total_number_of_packages: NotRequired[float]
    r"""The total number of packages of the goods"""
    total_packages_uom: NotRequired[str]
    r"""The unit of measurement for the goods"""
    total_weight: NotRequired[float]
    r"""The total weight of the shipment"""
    total_weight_uom: NotRequired[str]
    r"""The unit of measurement used for the weight"""
    total_volume: NotRequired[float]
    r"""The total volume of the shipment"""
    total_volume_uom: NotRequired[str]
    r"""The unit of measurement used for the volume"""


class InternationalConsignmentNoteFieldsTotals(BaseModel):
    total_number_of_packages: Annotated[
        Optional[float], pydantic.Field(alias="totalNumberOfPackages")
    ] = None
    r"""The total number of packages of the goods"""

    total_packages_uom: Annotated[
        Optional[str], pydantic.Field(alias="totalPackagesUom")
    ] = None
    r"""The unit of measurement for the goods"""

    total_weight: Annotated[Optional[float], pydantic.Field(alias="totalWeight")] = None
    r"""The total weight of the shipment"""

    total_weight_uom: Annotated[
        Optional[str], pydantic.Field(alias="totalWeightUom")
    ] = None
    r"""The unit of measurement used for the weight"""

    total_volume: Annotated[Optional[float], pydantic.Field(alias="totalVolume")] = None
    r"""The total volume of the shipment"""

    total_volume_uom: Annotated[
        Optional[str], pydantic.Field(alias="totalVolumeUom")
    ] = None
    r"""The unit of measurement used for the volume"""


class LoadingTypedDict(TypedDict):
    arrival_date: NotRequired[date]
    r"""The arrival date of the transport for loading"""
    arrival_time: NotRequired[str]
    r"""The arrival time of the transport for loading"""
    departure_date: NotRequired[date]
    r"""The departure date of the transport after loading"""
    departure_time: NotRequired[str]
    r"""The departure time of the transport after loading"""


class Loading(BaseModel):
    arrival_date: Annotated[Optional[date], pydantic.Field(alias="arrivalDate")] = None
    r"""The arrival date of the transport for loading"""

    arrival_time: Annotated[Optional[str], pydantic.Field(alias="arrivalTime")] = None
    r"""The arrival time of the transport for loading"""

    departure_date: Annotated[Optional[date], pydantic.Field(alias="departureDate")] = (
        None
    )
    r"""The departure date of the transport after loading"""

    departure_time: Annotated[Optional[str], pydantic.Field(alias="departureTime")] = (
        None
    )
    r"""The departure time of the transport after loading"""


class DischargeTypedDict(TypedDict):
    arrival_date: NotRequired[date]
    r"""The arrival date of the transport for discharge"""
    arrival_time: NotRequired[str]
    r"""The arrival time of the transport for discharge"""
    departure_date: NotRequired[date]
    r"""The departure date of the transport after discharge"""
    departure_time: NotRequired[str]
    r"""The departure time of the transport after discharge"""


class Discharge(BaseModel):
    arrival_date: Annotated[Optional[date], pydantic.Field(alias="arrivalDate")] = None
    r"""The arrival date of the transport for discharge"""

    arrival_time: Annotated[Optional[str], pydantic.Field(alias="arrivalTime")] = None
    r"""The arrival time of the transport for discharge"""

    departure_date: Annotated[Optional[date], pydantic.Field(alias="departureDate")] = (
        None
    )
    r"""The departure date of the transport after discharge"""

    departure_time: Annotated[Optional[str], pydantic.Field(alias="departureTime")] = (
        None
    )
    r"""The departure time of the transport after discharge"""


class InternationalConsignmentNoteFieldsTypedDict(TypedDict):
    r"""Fields extracted from an international consignment note"""

    shipper: NotRequired[InternationalConsignmentNoteFieldsShipperTypedDict]
    consignee: NotRequired[InternationalConsignmentNoteFieldsConsigneeTypedDict]
    carrier: NotRequired[InternationalConsignmentNoteFieldsCarrierTypedDict]
    successive_carrier: NotRequired[SuccessiveCarrierTypedDict]
    place_of_delivery_of_goods: NotRequired[PlaceOfDeliveryOfGoodsTypedDict]
    place_and_date_of_taking_over_of_goods: NotRequired[
        PlaceAndDateOfTakingOverOfGoodsTypedDict
    ]
    list_of_annexed_documents: NotRequired[List[str]]
    line_items: NotRequired[List[InternationalConsignmentNoteFieldsLineItemsTypedDict]]
    totals: NotRequired[InternationalConsignmentNoteFieldsTotalsTypedDict]
    document_number: NotRequired[str]
    r"""The consignment note number"""
    place_of_issue: NotRequired[str]
    r"""The consignment note place of issue"""
    date_of_issue: NotRequired[date]
    r"""The consignment note date of issue"""
    loading: NotRequired[LoadingTypedDict]
    discharge: NotRequired[DischargeTypedDict]
    terms_of_delivery: NotRequired[str]
    r"""The delivery terms. This field can contain any names, three-letter codes, or Incoterms rule names in full: EXW (EX Works), FCA (Free Carrier), FAS (Free Alongside Ship), FOB (Free On Board), CFR (Cost And Freight), CNF (another variant for Cost And Freight), CIF (Cost Insurance Freight), DAP (Delivered At Place), DTU (another variant for Delivered At Place, replace with DAP), DPU (Delivered at Place Unloaded), CPT (Carriage Paid To), CIP (Carriage Insurance Paid), DDP (Delivered Duty Paid), DDU (Delivered Duty Unpaid)"""
    value_of_goods: NotRequired[float]
    r"""The declared value of the goods"""
    currency: NotRequired[str]
    r"""The currency of the amounts in the consignment note"""
    senders_instructions: NotRequired[str]
    r"""The shipper's special instructions"""
    carrier_remarks: NotRequired[str]
    r"""The remarks of the carrier regarding the state and packaging of the goods"""
    special_agreements_of_carriage: NotRequired[str]
    r"""Special shipping agreements"""
    number_plate: NotRequired[str]
    r"""The registration number of the transport"""
    trailer_number_plate: NotRequired[str]
    r"""The registration number of the trailer"""
    goods_received_date: NotRequired[date]
    r"""The date on which the goods are received"""


class InternationalConsignmentNoteFields(BaseModel):
    r"""Fields extracted from an international consignment note"""

    shipper: Optional[InternationalConsignmentNoteFieldsShipper] = None

    consignee: Optional[InternationalConsignmentNoteFieldsConsignee] = None

    carrier: Optional[InternationalConsignmentNoteFieldsCarrier] = None

    successive_carrier: Annotated[
        Optional[SuccessiveCarrier], pydantic.Field(alias="successiveCarrier")
    ] = None

    place_of_delivery_of_goods: Annotated[
        Optional[PlaceOfDeliveryOfGoods], pydantic.Field(alias="placeOfDeliveryOfGoods")
    ] = None

    place_and_date_of_taking_over_of_goods: Annotated[
        Optional[PlaceAndDateOfTakingOverOfGoods],
        pydantic.Field(alias="placeAndDateOfTakingOverOfGoods"),
    ] = None

    list_of_annexed_documents: Annotated[
        Optional[List[str]], pydantic.Field(alias="listOfAnnexedDocuments")
    ] = None

    line_items: Annotated[
        Optional[List[InternationalConsignmentNoteFieldsLineItems]],
        pydantic.Field(alias="lineItems"),
    ] = None

    totals: Optional[InternationalConsignmentNoteFieldsTotals] = None

    document_number: Annotated[
        Optional[str], pydantic.Field(alias="documentNumber")
    ] = None
    r"""The consignment note number"""

    place_of_issue: Annotated[Optional[str], pydantic.Field(alias="placeOfIssue")] = (
        None
    )
    r"""The consignment note place of issue"""

    date_of_issue: Annotated[Optional[date], pydantic.Field(alias="dateOfIssue")] = None
    r"""The consignment note date of issue"""

    loading: Optional[Loading] = None

    discharge: Optional[Discharge] = None

    terms_of_delivery: Annotated[
        Optional[str], pydantic.Field(alias="termsOfDelivery")
    ] = None
    r"""The delivery terms. This field can contain any names, three-letter codes, or Incoterms rule names in full: EXW (EX Works), FCA (Free Carrier), FAS (Free Alongside Ship), FOB (Free On Board), CFR (Cost And Freight), CNF (another variant for Cost And Freight), CIF (Cost Insurance Freight), DAP (Delivered At Place), DTU (another variant for Delivered At Place, replace with DAP), DPU (Delivered at Place Unloaded), CPT (Carriage Paid To), CIP (Carriage Insurance Paid), DDP (Delivered Duty Paid), DDU (Delivered Duty Unpaid)"""

    value_of_goods: Annotated[Optional[float], pydantic.Field(alias="valueOfGoods")] = (
        None
    )
    r"""The declared value of the goods"""

    currency: Optional[str] = None
    r"""The currency of the amounts in the consignment note"""

    senders_instructions: Annotated[
        Optional[str], pydantic.Field(alias="sendersInstructions")
    ] = None
    r"""The shipper's special instructions"""

    carrier_remarks: Annotated[
        Optional[str], pydantic.Field(alias="carrierRemarks")
    ] = None
    r"""The remarks of the carrier regarding the state and packaging of the goods"""

    special_agreements_of_carriage: Annotated[
        Optional[str], pydantic.Field(alias="specialAgreementsOfCarriage")
    ] = None
    r"""Special shipping agreements"""

    number_plate: Annotated[Optional[str], pydantic.Field(alias="numberPlate")] = None
    r"""The registration number of the transport"""

    trailer_number_plate: Annotated[
        Optional[str], pydantic.Field(alias="trailerNumberPlate")
    ] = None
    r"""The registration number of the trailer"""

    goods_received_date: Annotated[
        Optional[date], pydantic.Field(alias="goodsReceivedDate")
    ] = None
    r"""The date on which the goods are received"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeliveryNoteFieldsBuyerTypedDict(TypedDict):
    r"""Buyer details"""

    buyer_id: NotRequired[str]
    r"""The unique identifier of the buyer in an external system"""
    name: NotRequired[str]
    r"""The name of the buyer"""
    address: NotRequired[str]
    r"""The address of the buyer"""
    tax_id: NotRequired[str]
    r"""The tax identification number of the buyer"""
    iban: NotRequired[str]
    r"""The buyer's international bank account number"""


class DeliveryNoteFieldsBuyer(BaseModel):
    r"""Buyer details"""

    buyer_id: Annotated[Optional[str], pydantic.Field(alias="buyerId")] = None
    r"""The unique identifier of the buyer in an external system"""

    name: Optional[str] = None
    r"""The name of the buyer"""

    address: Optional[str] = None
    r"""The address of the buyer"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The tax identification number of the buyer"""

    iban: Optional[str] = None
    r"""The buyer's international bank account number"""


class DeliveryNoteFieldsVendorTypedDict(TypedDict):
    r"""Vendor details"""

    vendor_id: NotRequired[str]
    r"""The unique identifier of the vendor in an external system"""
    name: NotRequired[str]
    r"""The name of the vendor"""
    address: NotRequired[str]
    r"""The address of the vendor"""
    tax_id: NotRequired[str]
    r"""The tax identification number of the vendor"""
    national_tax_id: NotRequired[str]
    r"""The national tax ID of the vendor"""
    iban: NotRequired[str]
    r"""The international bank account number of the vendor"""
    bank_code: NotRequired[str]
    r"""The bank code of the vendor"""
    bank_account: NotRequired[str]
    r"""The bank account number of the vendor"""


class DeliveryNoteFieldsVendor(BaseModel):
    r"""Vendor details"""

    vendor_id: Annotated[Optional[str], pydantic.Field(alias="vendorId")] = None
    r"""The unique identifier of the vendor in an external system"""

    name: Optional[str] = None
    r"""The name of the vendor"""

    address: Optional[str] = None
    r"""The address of the vendor"""

    tax_id: Annotated[Optional[str], pydantic.Field(alias="taxId")] = None
    r"""The tax identification number of the vendor"""

    national_tax_id: Annotated[Optional[str], pydantic.Field(alias="nationalTaxId")] = (
        None
    )
    r"""The national tax ID of the vendor"""

    iban: Optional[str] = None
    r"""The international bank account number of the vendor"""

    bank_code: Annotated[Optional[str], pydantic.Field(alias="bankCode")] = None
    r"""The bank code of the vendor"""

    bank_account: Annotated[Optional[str], pydantic.Field(alias="bankAccount")] = None
    r"""The bank account number of the vendor"""


class DeliveryNoteFieldsShipToTypedDict(TypedDict):
    r"""The recipient of the goods or services"""

    name: NotRequired[str]
    r"""The name of the recipient of the goods or services"""
    address: NotRequired[str]
    r"""The address where the goods must be delivered"""


class DeliveryNoteFieldsShipTo(BaseModel):
    r"""The recipient of the goods or services"""

    name: Optional[str] = None
    r"""The name of the recipient of the goods or services"""

    address: Optional[str] = None
    r"""The address where the goods must be delivered"""


class DeliveryNoteFieldsBillToTypedDict(TypedDict):
    r"""The recipient of the invoice"""

    name: NotRequired[str]
    r"""The name of the recipient of the invoice"""
    address: NotRequired[str]
    r"""The address where the invoice must be sent"""


class DeliveryNoteFieldsBillTo(BaseModel):
    r"""The recipient of the invoice"""

    name: Optional[str] = None
    r"""The name of the recipient of the invoice"""

    address: Optional[str] = None
    r"""The address where the invoice must be sent"""


class AmountsTypedDict(TypedDict):
    r"""Amount information"""

    total: NotRequired[float]
    r"""The total amount specified in the delivery note"""
    currency: NotRequired[str]
    r"""The currency of the total amount"""


class Amounts(BaseModel):
    r"""Amount information"""

    total: Optional[float] = None
    r"""The total amount specified in the delivery note"""

    currency: Optional[str] = None
    r"""The currency of the total amount"""


class DeliveryNoteFieldsTaxesTypedDict(TypedDict):
    r"""Tax information"""

    tax: NotRequired[float]
    r"""The total tax amount"""


class DeliveryNoteFieldsTaxes(BaseModel):
    r"""Tax information"""

    tax: Optional[float] = None
    r"""The total tax amount"""


class AdditionalCostsTypedDict(TypedDict):
    r"""Additional costs"""

    additional_cost: NotRequired[float]


class AdditionalCosts(BaseModel):
    r"""Additional costs"""

    additional_cost: Annotated[
        Optional[float], pydantic.Field(alias="additionalCost")
    ] = None


class DeliveryNoteFieldsLineItemsTypedDict(TypedDict):
    r"""Line item details"""

    item_number: NotRequired[str]
    r"""The item number"""
    order_number: NotRequired[str]
    r"""The order number"""
    article_number: NotRequired[str]
    r"""The article number"""
    description: NotRequired[str]
    r"""A description of the line item"""
    quantity_ordered: NotRequired[float]
    r"""The number of units ordered"""
    unit_price: NotRequired[float]
    r"""The price of one item of goods"""
    total_price: NotRequired[float]
    r"""The price of the line item including tax"""
    currency: NotRequired[str]
    r"""The currency of the line item"""
    delivery_date: NotRequired[date]
    r"""The planned delivery date for the line item"""
    quantity_delivered: NotRequired[float]
    r"""The number of units delivered"""
    unit_of_measurement: NotRequired[str]
    r"""The unit of measurement used for the goods"""
    net_weight: NotRequired[float]
    r"""The net weight of the line item"""
    gross_weight: NotRequired[float]
    r"""The gross weight of the line item"""
    weight_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the weight of the line item (kilograms, pounds, etc.)"""
    serial_number: NotRequired[str]
    r"""A unique identifier assigned to each item of goods"""
    batch_number: NotRequired[str]
    r"""A unique identifier assigned to a specific group or batch of items that are being transported or delivered together"""
    ean_number: NotRequired[str]
    r"""A unique identifier from the European Article Numbering (EAN) system"""


class DeliveryNoteFieldsLineItems(BaseModel):
    r"""Line item details"""

    item_number: Annotated[Optional[str], pydantic.Field(alias="itemNumber")] = None
    r"""The item number"""

    order_number: Annotated[Optional[str], pydantic.Field(alias="orderNumber")] = None
    r"""The order number"""

    article_number: Annotated[Optional[str], pydantic.Field(alias="articleNumber")] = (
        None
    )
    r"""The article number"""

    description: Optional[str] = None
    r"""A description of the line item"""

    quantity_ordered: Annotated[
        Optional[float], pydantic.Field(alias="quantityOrdered")
    ] = None
    r"""The number of units ordered"""

    unit_price: Annotated[Optional[float], pydantic.Field(alias="unitPrice")] = None
    r"""The price of one item of goods"""

    total_price: Annotated[Optional[float], pydantic.Field(alias="totalPrice")] = None
    r"""The price of the line item including tax"""

    currency: Optional[str] = None
    r"""The currency of the line item"""

    delivery_date: Annotated[Optional[date], pydantic.Field(alias="deliveryDate")] = (
        None
    )
    r"""The planned delivery date for the line item"""

    quantity_delivered: Annotated[
        Optional[float], pydantic.Field(alias="quantityDelivered")
    ] = None
    r"""The number of units delivered"""

    unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="unitOfMeasurement")
    ] = None
    r"""The unit of measurement used for the goods"""

    net_weight: Annotated[Optional[float], pydantic.Field(alias="netWeight")] = None
    r"""The net weight of the line item"""

    gross_weight: Annotated[Optional[float], pydantic.Field(alias="grossWeight")] = None
    r"""The gross weight of the line item"""

    weight_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="weightUnitOfMeasurement")
    ] = None
    r"""The unit of measurement for the weight of the line item (kilograms, pounds, etc.)"""

    serial_number: Annotated[Optional[str], pydantic.Field(alias="serialNumber")] = None
    r"""A unique identifier assigned to each item of goods"""

    batch_number: Annotated[Optional[str], pydantic.Field(alias="batchNumber")] = None
    r"""A unique identifier assigned to a specific group or batch of items that are being transported or delivered together"""

    ean_number: Annotated[Optional[str], pydantic.Field(alias="eanNumber")] = None
    r"""A unique identifier from the European Article Numbering (EAN) system"""


class DeliveryNoteFieldsTypedDict(TypedDict):
    r"""Fields extracted from a delivery note"""

    buyer: NotRequired[DeliveryNoteFieldsBuyerTypedDict]
    r"""Buyer details"""
    vendor: NotRequired[DeliveryNoteFieldsVendorTypedDict]
    r"""Vendor details"""
    ship_to: NotRequired[DeliveryNoteFieldsShipToTypedDict]
    r"""The recipient of the goods or services"""
    bill_to: NotRequired[DeliveryNoteFieldsBillToTypedDict]
    r"""The recipient of the invoice"""
    delivery_note_number: NotRequired[str]
    r"""The number of the delivery note"""
    delivery_note_date: NotRequired[date]
    r"""The date on which the delivery note was issued"""
    delivery_date: NotRequired[date]
    r"""The date on which the goods are expected to be delivered"""
    due_date: NotRequired[date]
    r"""The date on which the goods are expected to be delivered"""
    shipping_date: NotRequired[date]
    r"""The date on which the goods are shipped"""
    purchaser_name: NotRequired[str]
    r"""The name of the buyer"""
    purchase_order_number: NotRequired[str]
    r"""The purchase order number (if one is specified in the document)"""
    purchase_order_date: NotRequired[date]
    r"""The date when the purchase order was created"""
    invoice_number: NotRequired[str]
    r"""The invoice number (if one is specified in the document)"""
    delivery_terms: NotRequired[str]
    r"""The delivery terms"""
    amounts: NotRequired[AmountsTypedDict]
    r"""Amount information"""
    taxes: NotRequired[List[DeliveryNoteFieldsTaxesTypedDict]]
    r"""Tax information"""
    additional_costs: NotRequired[AdditionalCostsTypedDict]
    r"""Additional costs"""
    total_net_weight: NotRequired[float]
    r"""The total net weight of the goods"""
    total_gross_weight: NotRequired[float]
    r"""The total gross weight of the goods"""
    weight_unit_of_measurement: NotRequired[str]
    r"""The unit of measurement for the weight of the goods (kilograms, pounds, etc.)"""
    line_items: NotRequired[List[DeliveryNoteFieldsLineItemsTypedDict]]
    r"""List of line items in the invoice"""


class DeliveryNoteFields(BaseModel):
    r"""Fields extracted from a delivery note"""

    buyer: Optional[DeliveryNoteFieldsBuyer] = None
    r"""Buyer details"""

    vendor: Optional[DeliveryNoteFieldsVendor] = None
    r"""Vendor details"""

    ship_to: Annotated[
        Optional[DeliveryNoteFieldsShipTo], pydantic.Field(alias="shipTo")
    ] = None
    r"""The recipient of the goods or services"""

    bill_to: Annotated[
        Optional[DeliveryNoteFieldsBillTo], pydantic.Field(alias="billTo")
    ] = None
    r"""The recipient of the invoice"""

    delivery_note_number: Annotated[
        Optional[str], pydantic.Field(alias="deliveryNoteNumber")
    ] = None
    r"""The number of the delivery note"""

    delivery_note_date: Annotated[
        Optional[date], pydantic.Field(alias="deliveryNoteDate")
    ] = None
    r"""The date on which the delivery note was issued"""

    delivery_date: Annotated[Optional[date], pydantic.Field(alias="deliveryDate")] = (
        None
    )
    r"""The date on which the goods are expected to be delivered"""

    due_date: Annotated[Optional[date], pydantic.Field(alias="dueDate")] = None
    r"""The date on which the goods are expected to be delivered"""

    shipping_date: Annotated[Optional[date], pydantic.Field(alias="shippingDate")] = (
        None
    )
    r"""The date on which the goods are shipped"""

    purchaser_name: Annotated[Optional[str], pydantic.Field(alias="purchaserName")] = (
        None
    )
    r"""The name of the buyer"""

    purchase_order_number: Annotated[
        Optional[str], pydantic.Field(alias="purchaseOrderNumber")
    ] = None
    r"""The purchase order number (if one is specified in the document)"""

    purchase_order_date: Annotated[
        Optional[date], pydantic.Field(alias="purchaseOrderDate")
    ] = None
    r"""The date when the purchase order was created"""

    invoice_number: Annotated[Optional[str], pydantic.Field(alias="invoiceNumber")] = (
        None
    )
    r"""The invoice number (if one is specified in the document)"""

    delivery_terms: Annotated[Optional[str], pydantic.Field(alias="deliveryTerms")] = (
        None
    )
    r"""The delivery terms"""

    amounts: Optional[Amounts] = None
    r"""Amount information"""

    taxes: Optional[List[DeliveryNoteFieldsTaxes]] = None
    r"""Tax information"""

    additional_costs: Annotated[
        Optional[AdditionalCosts], pydantic.Field(alias="additionalCosts")
    ] = None
    r"""Additional costs"""

    total_net_weight: Annotated[
        Optional[float], pydantic.Field(alias="totalNetWeight")
    ] = None
    r"""The total net weight of the goods"""

    total_gross_weight: Annotated[
        Optional[float], pydantic.Field(alias="totalGrossWeight")
    ] = None
    r"""The total gross weight of the goods"""

    weight_unit_of_measurement: Annotated[
        Optional[str], pydantic.Field(alias="weightUnitOfMeasurement")
    ] = None
    r"""The unit of measurement for the weight of the goods (kilograms, pounds, etc.)"""

    line_items: Annotated[
        Optional[List[DeliveryNoteFieldsLineItems]], pydantic.Field(alias="lineItems")
    ] = None
    r"""List of line items in the invoice"""
